﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Vista.RPC.Exceptions;
using Vista.RPC.Procedures.XUS;
using Vista.RPC.Procedures.XWB;

namespace Vista.RPC
{
    [TestClass]
    public class ConnectUnitTest : BaseRpcTest
    {
        [TestMethod]
        public void ConnectToClaimsSuccess()
        {
            var logger = RpcLogging.CreateLogger<RpcClient>();
            RpcClient rpcClient =
                new RpcClient(logger, TestConfig.Get(Config.CLAIMS_HOSTNAME), TestConfig.Get(Config.CLAIMS_PORT));
            Assert.IsFalse(rpcClient.Connected);

            try
            {
                rpcClient.Connect();
            }
            catch (ConnectException)
            {
                Assert.Fail("Connect should NOT fail");
            }

            Assert.IsTrue(rpcClient.Connected);
            rpcClient.Disconnect();
            Assert.IsFalse(rpcClient.Connected);
        }

        [TestMethod]
        public void ConnectToUnknownVista()
        {
            var logger = RpcLogging.CreateLogger<RpcClient>();
            RpcClient rpcClient = new RpcClient(logger, "a.b.c.d", "1234");
            Assert.IsFalse(rpcClient.Connected);

            try
            {
                rpcClient.Connect();
            }
            catch (ConnectException connectException)
            {
                Assert.IsNotNull(connectException.Message);
            }

            Assert.IsFalse(rpcClient.Connected);
            rpcClient.Disconnect();
            Assert.IsFalse(rpcClient.Connected);
        }

        [TestMethod]
        public void ConnectAndLoginToTestClaims()
        {
            RpcClient rpcClient = GetRpcClient(true);
            rpcClient.Connect();

            var loginResponse = rpcClient.Login(TestConfig.Get(Config.TEST_CLAIMS_ACCESS_CODE).ToSecureString(),
                TestConfig.Get(Config.TEST_CLAIMS_VERIFY_CODE).ToSecureString());

            Assert.IsTrue(loginResponse.LoggedIn, "failed to login");

            var createContext = new CreateContext(CreateContext.CONTEXT_VRAM.ToSecureString());
            rpcClient.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid, "failed to switch to context");

            VisitorSet remoteProcedure = new VisitorSet();
            rpcClient.Call(remoteProcedure);

            String token = remoteProcedure.GetVisitorToken();
            Console.WriteLine("Token: " + token);
            Assert.IsFalse(string.IsNullOrEmpty(token), "failed to retrieve token");
            Assert.IsTrue(token.Length > 0, "token length should be > 0");

            rpcClient.Disconnect();
        }

        [TestMethod]
        public void ConnectAndLoginToTestVista()
        {
            RpcClient c = GetRpcClient();
            c.Connect();

            c.Login(TestConfig.Get(Config.TEST_VISTA_ACCESS_CODE).ToSecureString(),
                TestConfig.Get(Config.TEST_VISTA_VERIFY_CODE).ToSecureString());

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI.ToSecureString());
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            VisitorSet remoteProcedure = new VisitorSet();
            c.Call(remoteProcedure);

            String token = remoteProcedure.GetVisitorToken();
            Console.WriteLine("Token: " + token);
            Assert.IsFalse(string.IsNullOrEmpty(token));
            Assert.IsTrue(token.Length > 0);

            c.Disconnect();
        }
    }
}