﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Vista.RPC.Procedures.XUS;
using Vista.RPC.Procedures.XWB;
using Vista.RPC.Procedures.DDR;
using System.Collections.Generic;

namespace Vista.RPC
{
    [TestClass]
    public class DdrFilerBaseRpcTest1 : BaseRpcTest
    {
        [TestMethod]
        public void Success_FILE_DIE_Test()
        {
            RpcClient c = ConnectAndLogin();

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI);
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            List<string> fdaRoot = new List<string>();
            fdaRoot.Add("500003^1^1^200");

            DdrFiler Filer = new DdrFiler(DdrFiler.DdrMode.FILE_DIE, "E", fdaRoot);
            c.Call(Filer);

            System.IO.File.WriteAllText(@"c:\temp\rpc\filer.txt", Filer.Response);

            c.Disconnect();
        }

        [TestMethod]
        public void Success_usingFDA_FILE_DIE_Test()
        {
            RpcClient c = ConnectAndLogin();

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI);
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            FileManDataArray fdaRoot = new FileManDataArray();
            fdaRoot.Add("500003", "1", "1", "999");
            fdaRoot.Add("500003", "1", "2", "222");

            DdrFiler Filer = new DdrFiler(DdrFiler.DdrMode.FILE_DIE, "E", fdaRoot);
            c.Call(Filer);

            System.IO.File.WriteAllText(@"c:\temp\rpc\filer.txt", Filer.Response);

            c.Disconnect();
        }

        [TestMethod]
        public void Failure_FILE_DIE_Test()
        {
            RpcClient c = ConnectAndLogin();

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI);
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            List<string> fdaRoot = new List<string>();
            fdaRoot.Add("500003^991^1^200");

            DdrFiler Filer = new DdrFiler(DdrFiler.DdrMode.FILE_DIE, "E", fdaRoot);
            c.Call(Filer);

            System.IO.File.WriteAllText(@"c:\temp\rpc\filer.txt", Filer.Response);

            c.Disconnect();
        }

        [TestMethod]
        public void Success_UPDATE_DIE_Test()
        {
            RpcClient c = ConnectAndLogin();

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI);
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            List<string> fdaRoot = new List<string>();
            fdaRoot.Add("500003^1^+1^200");
            fdaRoot.Add("500003^.01^+1^CCC");

            DdrFiler Filer = new DdrFiler(DdrFiler.DdrMode.UPDATE_DIE, "E", fdaRoot);
            c.Call(Filer);

            System.IO.File.WriteAllText(@"c:\temp\rpc\filer.txt", Filer.Response);

            c.Disconnect();
        }

        [TestMethod]
        public void Failure_UPDATE_DIE_Test()
        {
            RpcClient c = ConnectAndLogin();

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI);
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            List<string> fdaRoot = new List<string>();

            DdrFiler Filer = new DdrFiler(DdrFiler.DdrMode.UPDATE_DIE, "E", fdaRoot);
            c.Call(Filer);

            System.IO.File.WriteAllText(@"c:\temp\rpc\filer.txt", Filer.Response);

            c.Disconnect();
        }
    }
}
