﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Vista.RPC.Procedures.DDR
{
    [TestClass]
    public class DdrFindOneUnitTest1 : BaseRpcTest
    {
        [TestMethod]
        public void FindOneSuccess()
        {
            var rpcClient = ConnectAndLogin(true);

            var findOne = new DdrFindOne(file: "19", lookupValue: "DIFG", flags: "X");
            rpcClient.Call(findOne);

            Assert.IsTrue(findOne.ResultOfQuery() == DdrFindOne.Result.MatchFound);
            Assert.IsNotNull(findOne.GetResult());

            try
            {
                Assert.IsTrue(int.Parse(findOne.GetResult()) > 0);
            }
            catch (Exception e)
            {
                Assert.Fail(e.Message);
            }
        }

        [TestMethod]
        public void FindOneExpectArgumentNullException()
        {
            try
            {
                var findOne = new DdrFindOne(file: "", lookupValue: "DIFG", flags: "X");
            }
            catch (ArgumentNullException e)
            {
                Assert.IsTrue(e.ParamName == "file");
            }
            catch (Exception e)
            {
                Assert.Fail("no other exception should be thrown", e);
            }

            try
            {
                var findOne = new DdrFindOne(file: "19", lookupValue: "", flags: "X");
            }
            catch (ArgumentNullException e)
            {
                Assert.IsTrue(e.ParamName == "lookupValue");
            }
            catch (Exception e)
            {
                Assert.Fail("no other exception should be thrown", e);
            }
        }

        [TestMethod]
        public void NoMatchFoundTest()
        {
            var rpcClient = ConnectAndLogin(true);

            var findOne = new DdrFindOne(file: "19", lookupValue: "DIFGXXXXXX", flags: "X");
            rpcClient.Call(findOne);

            Assert.IsTrue(findOne.ResultOfQuery() == DdrFindOne.Result.NoMatchFound);
            Assert.IsTrue(findOne.GetResult().Equals("0"));
        }

        [TestMethod]
        public void BadFileErrorTest()
        {
            var rpcClient = ConnectAndLogin(true);

            var findOne = new DdrFindOne(file: "9876543210", lookupValue: "DIFGXXXXXX", flags: "X");
            rpcClient.Call(findOne);

            Assert.IsTrue(findOne.ResultOfQuery() == DdrFindOne.Result.Error);
        }
    }
}
