﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Vista.RPC.Procedures.XUS;
using Vista.RPC.Procedures.XWB;
using Vista.RPC.Procedures.DDR;
using System.Collections.Generic;

namespace Vista.RPC
{
    [TestClass]
    public class DdrListerUnitTest1 : BaseRpcTest
    {
        [TestMethod]
        public void ErrorsTest()
        {
            RpcClient c = GetRpcClient();
            c.Connect();

            c.Login(TestConfig.Get(Config.TEST_VISTA_ACCESS_CODE).ToSecureString(),
                TestConfig.Get(Config.TEST_VISTA_VERIFY_CODE).ToSecureString());

            CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI.ToSecureString());
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            DdrLister Lister = new DdrLister("2","","@;.01;.02;.03;98769999","P","10");
            c.Call(Lister);

            System.IO.File.WriteAllText(@"c:\temp\rpc\lister.txt", Lister.Response);

            c.Disconnect();
        }

        [TestMethod]
        public void SuccessPackedTest()
        {
            RpcClient c = GetRpcClient();
            c.Connect();

            c.Login(TestConfig.Get(Config.TEST_VISTA_ACCESS_CODE).ToSecureString(),
                TestConfig.Get(Config.TEST_VISTA_VERIFY_CODE).ToSecureString());

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI.ToSecureString());
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            DdrLister Lister = new DdrLister("2", "", "@;.01;.02;.03;", "P", "40");
            c.Call(Lister);

            System.IO.File.WriteAllText(@"c:\temp\rpc\lister-packed.txt", Lister.Response);

            Dictionary<string,string> row = Lister.GetRowByIen("7170445");
            foreach (String key in row.Keys)
            {
                Console.WriteLine(key + " --> " + row[key]);
            }

            c.Disconnect();
        }

        [TestMethod]
        public void SuccessTest()
        {
            RpcClient c = GetRpcClient();
            c.Connect();

            c.Login(TestConfig.Get(Config.TEST_VISTA_ACCESS_CODE).ToSecureString(),
                TestConfig.Get(Config.TEST_VISTA_VERIFY_CODE).ToSecureString());

            var createContext = new CreateContext(CreateContext.CONTEXT_CAPRI.ToSecureString());
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            DdrLister Lister = new DdrLister("2", "", "@;.01;.02;.03;", "", "10");
            c.Call(Lister);

            System.IO.File.WriteAllText(@"c:\temp\rpc\lister.txt", Lister.Response);

            Dictionary<string, string> row = Lister.GetRowByIen("7169038");
            foreach (String key in row.Keys)
            {
                Console.WriteLine(key + " --> " + row[key]);
            }

            row = Lister.GetRowByIen("7170713");
            foreach (String key in row.Keys)
            {
                Console.WriteLine(key + " --> " + row[key]);
            }

            c.Disconnect();
        }

        [TestMethod]
        public void SuccessIenPackedTest()
        {
            RpcClient c = BaseRpcTest.ConnectAndLogin();

            Vista.RPC.Procedures.XWB.CreateContext createContext = new CreateContext(CreateContext.CONTEXT_CAPRI.ToSecureString());
            c.Call(createContext);

            bool isValid = createContext.IsValidContext();
            Assert.IsTrue(isValid);

            string screen = "I $P(^DIC(19.1,$P(^VA(200,Y(1),51,Y,0),U),0),U)'[\"XUPROG\"";
            DdrLister Lister = new DdrLister("200.051", ",10000000390,", "@;.01;", "P", "", "", "", "", screen);            
            c.Call(Lister);

            System.IO.File.WriteAllText(@"c:\temp\rpc\lister-packed.txt", Lister.Response);

            Dictionary<string, Dictionary<string,string>> row = Lister.GetAllRows();
            foreach (String key in row.Keys)
            {
                Console.WriteLine(key + "--> " + row[key][".01"]);
            }

            c.Disconnect();
        }

        
    }
}
