﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace Vista.RPC.Procedures.XOBE
{
    [TestClass]
    public class EsigSetCodeUnitTest1 : BaseRpcTest
    {
        [TestMethod]
        public void TestValidEsignature()
        {
            var rpcClient = ConnectAndLogin();
            var eSignatureCode = "ABC" + Math.Abs(new Random().Next()*5);
            var remoteProcedure = new ElectronicSignatureSetCode(eSignatureCode);

            rpcClient.Call(remoteProcedure);

            Assert.IsTrue(remoteProcedure.Response.Length > 0);
            Assert.IsTrue(remoteProcedure.IsElectronicSignatureSet());
            Console.WriteLine("Given eSignature: " + eSignatureCode);
            Console.WriteLine("Response: " + remoteProcedure.Response);
        }

        [TestMethod]
        public void TestEmptyEsignature()
        {
            var rpcClient = ConnectAndLogin();
            var eSignatureCode = "";
            var remoteProcedure = new ElectronicSignatureSetCode(eSignatureCode);

            rpcClient.Call(remoteProcedure);

            Assert.IsTrue(remoteProcedure.Response.Length > 0);
            Assert.IsFalse(remoteProcedure.IsElectronicSignatureSet());

            Assert.IsTrue(remoteProcedure.Response.Trim().Equals("0"));
            Console.WriteLine(remoteProcedure.GetMessage());

            Console.WriteLine("Given eSignature: " + eSignatureCode);
            Console.WriteLine("Response: " + remoteProcedure.Response);
        }

        [TestMethod]
        public void TestAlreadyUsedEsignature()
        {
            var rpcClient = ConnectAndLogin();
            var eSignatureCode = "ABC" + Math.Abs(new Random().Next() * 5);
            
            var remoteProcedure = new ElectronicSignatureSetCode(eSignatureCode);
            rpcClient.Call(remoteProcedure); // call #1

            Assert.IsTrue(remoteProcedure.IsElectronicSignatureSet());

            rpcClient.Call(remoteProcedure); // call #2

            Assert.IsFalse(remoteProcedure.IsElectronicSignatureSet());

            Assert.IsTrue(remoteProcedure.Response.Trim().Equals("-1"));
            Console.WriteLine(remoteProcedure.GetMessage());

            Console.WriteLine("Given eSignature: " + eSignatureCode);
            Console.WriteLine("Response: " + remoteProcedure.Response);
        }
    }
}
