﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Vista.RPC.Procedures;

namespace Vista.RPC
{
    public static class RemoteProcedureExtension
    {
        /// <summary>
        /// This method is only available in the *.Tests projects; it allows you to set the remote procedures
        /// response so that a developer can unit test.
        /// </summary>
        /// <param name="remoteProcedure">the remote procedure that we want to set the response</param>
        /// <param name="response">the string response</param>
        /// <returns>remote procedure with the set response</returns>
        public static IRemoteProcedure SetResponse(this IRemoteProcedure remoteProcedure, string response)
        {
            var responseProperty = remoteProcedure.GetType().GetProperty("Response");

            if (responseProperty == null)
            {
                throw new ArgumentNullException("Response", "unable to find a Response property");
            }

            responseProperty.SetValue(remoteProcedure, response);
            return remoteProcedure;
        }
    }

    [TestClass]
    public class RemoteProcedureExtensionTest
    {
        [TestMethod]
        public void TestSetResponse()
        {
            var remoteProcedure = new RemoteProcedure("XWB IM HERE");
            Assert.IsTrue(string.IsNullOrEmpty(remoteProcedure.Response));

            var responseValue = "TEST123";

            remoteProcedure.SetResponse(responseValue);
            Assert.IsTrue(remoteProcedure.Response == responseValue);
        }
    }
}
