﻿using System;
using System.Threading;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Vista.RPC.Exceptions;
using Vista.RPC.Procedures.XUS;

namespace Vista.RPC
{
    [TestClass]
    public class RpcClientTimerUnitTest : BaseRpcTest
    {
        [TestMethod]
        public void TimerTest1()
        {
            RpcClient rpcClient = GetRpcClient();
            rpcClient.Connect();

            IntroMsg message = new IntroMsg();
            rpcClient.Call(message);

            Console.WriteLine(message.Response);
            Assert.IsNotNull(message.Response);
            Assert.IsTrue(message.Response.Length > 0);

            Assert.IsTrue(rpcClient.RpcReadTimeout > 0);

            try
            {
                int timeOut = (int) (rpcClient.RpcReadTimeout*1000);
                timeOut = timeOut + (1000*30);
                Thread.Sleep(timeOut);
            }
            catch (Exception e)
            {
                Assert.Fail("Timeout exception should not be thrown.");
            }

            message = new IntroMsg();
            rpcClient.Call(message);

            Assert.IsNotNull(message.Response);
            Assert.IsTrue(message.Response.Length > 0);

            rpcClient.Disconnect();
            Assert.IsFalse(rpcClient.Connected);
        }

        [TestMethod]
        public void LongTimerTest1()
        {
            RpcClient rpcClient = GetRpcClient();
            rpcClient.Connect();

            IntroMsg message = new IntroMsg();
            rpcClient.Call(message);

            Console.WriteLine(message.Response);
            Assert.IsNotNull(message.Response);
            Assert.IsTrue(message.Response.Length > 0);

            Assert.IsTrue(rpcClient.RpcReadTimeout > 0);

            try
            {
                int timeOut = (int)(rpcClient.RpcReadTimeout * 1000)*5;
                Thread.Sleep(timeOut);
            }
            catch (Exception e)
            {
                Assert.Fail("Timeout exception should not be thrown.");
            }

            message = new IntroMsg();
            rpcClient.Call(message);

            Assert.IsNotNull(message.Response);
            Assert.IsTrue(message.Response.Length > 0);

            rpcClient.Disconnect();
            Assert.IsFalse(rpcClient.Connected);
        }

        [TestMethod]
        public void DisableTimerTest()
        {
            RpcClient rpcClient = GetRpcClient();
            rpcClient.Connect();

            IntroMsg message = new IntroMsg();
            rpcClient.Call(message);

            Console.WriteLine(message.Response);
            Assert.IsNotNull(message.Response);
            Assert.IsTrue(message.Response.Length > 0, "Response should be greater than zero");

            Assert.IsTrue(rpcClient.RpcReadTimeout > 0, "RPC read timeout should be greater than zero");

            try
            {
                int timeOut = (int)(rpcClient.RpcReadTimeout * 1000);
                timeOut = timeOut + (1000*30);
                Thread.Sleep(timeOut);
            }
            catch (Exception e)
            {
                Assert.Fail("Timeout exception should not be thrown.");
            }

            try
            {
                rpcClient.Call(new IntroMsg());
            }
            catch (ConnectException e)
            {

            }
            catch (Exception e)
            {
                Assert.Fail("The general exception should not be thrown.");
            }

            Assert.IsFalse(rpcClient.Connected, "rpc client should be disconnected");
        }
    }
}
