﻿using System;
using System.Runtime.InteropServices;
using System.Security;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Vista.RPC.Procedures.XUS;

namespace Vista.RPC
{
    [TestClass]
    public class StringExtensionTest
    {
        [TestMethod]
        public void GetSecureRandomIntTest()
        {
            for (int i = 0; i < 1000; i++)
            {
                var randomInt = StringExtension.GetSecureRandomInt(0, 20);

                Console.WriteLine(randomInt);
                
                Assert.IsFalse(randomInt > 19);
                Assert.IsTrue(randomInt <= 19);
                Assert.IsTrue(randomInt >= 0);
                
            }
        }

        [TestMethod]
        public void SecureStringToString()
        {
            // arrange
            var s1 = new SecureString();
            s1.AppendChar('A');
            s1.AppendChar('B');

            // act
            var s = s1.ToClearText();

            // assert
            Assert.IsTrue(s == "AB");
        }

        [TestMethod]
        public void ConcatSecureStrings()
        {
            // arrange
            var s1 = new SecureString();
            s1.AppendChar('A');

            var s2 = new SecureString();
            s2.AppendChar('B');

            var s3 = new SecureString();
            s3.AppendChar('C');

            // act
            var result = s1.Concat(s2, s3).ToClearText();

            // assert
            Assert.IsTrue(result == "ABC");
        }

        [TestMethod]
        public void ExperimentWithSecureString()
        {
            var secureString = new SecureString();
            secureString.AppendChar('T');
            secureString.AppendChar('e');
            secureString.AppendChar('s');
            secureString.AppendChar('t');

            IntPtr pointer = IntPtr.Zero;
            byte b = 0;

            try
            {
                pointer = Marshal.SecureStringToGlobalAllocAnsi(secureString);

                b = Marshal.ReadByte(pointer, 0);            
                Assert.IsTrue('T' == (char) b);
                Assert.IsTrue(0x54 == b);
                Assert.IsTrue(84 == b);

                b = Marshal.ReadByte(pointer, 1);
                Assert.IsTrue('e' == (char)b);

                b = Marshal.ReadByte(pointer, 4);
                Assert.IsTrue(0 == b);
            }
            finally
            {
                IntPtr copyIntPtr = new IntPtr(pointer.ToInt64());

                Marshal.ZeroFreeGlobalAllocAnsi(pointer);

                Assert.IsTrue(copyIntPtr.ToInt64() == pointer.ToInt64());

                b = Marshal.ReadByte(pointer, 0);
                Assert.IsTrue('T' != (char) b);
                Assert.IsTrue(0x54 != b);
                Assert.IsTrue(84 != b);

                Console.WriteLine(b);
                
            }
   
        }

        // unsafe encryption method; allows heap inspection; keeping for reference
        /*
        public static string Encrypt(this String value)
        {
            string unencryptedValue = value;

            const int MAX_KEY = 19; // CIPHER_PAD.Length - 1;

            Random r = new Random();
            int associatorIndex = 3; //r.Next(MAX_KEY);
            int identifierIndex = 0;

            do
            {
                identifierIndex = r.Next(MAX_KEY);
            } while (associatorIndex == identifierIndex);

            identifierIndex = 4;

            String result = "";
            for (int i = 0; i < unencryptedValue.Length; i++)
            {
                char inChar = unencryptedValue[i];
                int pos = CIPHER_PAD[associatorIndex].IndexOf(inChar);
                if (pos == -1)
                {
                    result += inChar;
                }
                else
                {
                    result += CIPHER_PAD[identifierIndex][pos];
                }
            }

            return (char)(associatorIndex + 32) + result + (char)(identifierIndex + 32);
        }
        */
    }
}
