﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security;
using System.Text;
using System.Threading.Tasks;
using Vista.RPC.Models;
using Vista.RPC.Procedures;

namespace Vista.RPC
{
    public class TestRpcClient : IRpcClient
    {
        protected string _host;
        protected int _port = 0;
        protected bool _preventTimeout = false;
        public List<List<object>> callList = new List<List<object>>();
        protected bool _connected = false;

        public TestRpcClient(string host, int port, bool preventTimeout)
        {
            _host = host;
            _port = port;
            _preventTimeout = preventTimeout;
        }

        public bool Connected => _connected;

        public void Call(IRemoteProcedure remoteProcedure)
        {
            remoteProcedure.ToProcedure();
            AddToCallList("Call", remoteProcedure);
        }

        public void CallAndDisconnect(IRemoteProcedure rpc)
        {
            AddToCallList("CallAndDisconnect", rpc);
            _connected = false;
        }

        public void Connect()
        {
            AddToCallList("Connect", "");
        }

        public bool CreateContext(SecureString contextString)
        {
            AddToCallList("CreateContext", contextString.ToClearText());
            return true;
        }

        public void Disconnect()
        {
            AddToCallList("Disconnect", "");
        }

        public LoginResponse Login(SecureString accessCode, SecureString verifyCode, SecureString menuOption)
        {
            AddToCallList("Login", new List<string>() {accessCode.ToClearText(), verifyCode.ToClearText(), menuOption.ToClearText()});
            LoginResponse response = new LoginResponse {LoggedIn = true, LoggedInDuz = "1234"};
            return response;
        }

        public LoginResponse Login(SecureString accessCode, SecureString verifyCode)
        {
            AddToCallList("Login", new List<string>() {accessCode.ToClearText(), verifyCode.ToClearText()});
            LoginResponse response = new LoginResponse {LoggedIn = true, LoggedInDuz = "4321"};
            return response;
        }

        protected virtual void AddToCallList(string callName, object parms)
        {
            List<object> callDetails = new List<object>() {callName, parms};
            callList.Add(callDetails);
        }

        public void Dispose()
        {
            
        }
    }
}