﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Vista.RPC.Parameters;

namespace Vista.RPC.Procedures.DDR
{
    public class DdrFiler : RemoteProcedure
    {
        public enum DdrMode 
        { 
            FILE_DIE,   /* this refers to M routine FILE^DIE   API -> http://www.hardhats.org/fileman/pm/db_die_f.htm */
            UPDATE,     /* also known as FILE_DIE ... NO I did NOT come up with that language - just following the FM API pattern */

            UPDATE_DIE, /* this refers to M routine UPDATE^DIE API -> http://www.hardhats.org/fileman/pm/db_die_u.htm */
            ADD         /* also known as UPDATE_DIE */
        }

        public DdrMode Mode
        {
            get;
            private set;
        }

        public DdrFiler(DdrMode mode, string flags, IFileManDataArray fdaRoot, List<string> ienRoot = null)
            : this(mode, flags, fdaRoot.ToFDA(), ienRoot) { }

        public DdrFiler(DdrMode mode, string flags, List<string> fdaRoot, List<string> ienRoot = null) : base("DDR FILER")
        {
            Mode = mode;

            if (mode == DdrMode.FILE_DIE || mode == DdrMode.UPDATE)
            {
                LiteralParameter modeParameter = new LiteralParameter("FILE");
                AddParameter(modeParameter);
            }
            else if (mode == DdrMode.UPDATE_DIE || mode == DdrMode.ADD)
            {
                LiteralParameter modeParameter = new LiteralParameter("ADD");
                AddParameter(modeParameter);
            }

            Dictionary<string, string> list = new Dictionary<string, string>();
            for (int i = 0; i < fdaRoot.Count; i++)
            {
                list.Add((i+1).ToString(), fdaRoot[i]);
            }
            ListParameter listParameter = new ListParameter(list);
            AddParameter(listParameter);

            LiteralParameter flagsParameter = new LiteralParameter(flags.ToUpper());
            AddParameter(flagsParameter);

            if (mode == DdrMode.UPDATE_DIE || mode == DdrMode.ADD)
            {
                if (null != ienRoot)
                {
                    Dictionary<string, string> ienList = new Dictionary<string, string>();
                    for (int i = 0; i < ienRoot.Count; i++)
                    {
                        ienList.Add((i + 1).ToString(), ienRoot[i]);
                    }
                    ListParameter ienListParameter = new ListParameter(ienList);
                    AddParameter(ienListParameter);
                }
            }
        }

        public override void AfterCall()
        {
            if (Mode == DdrMode.UPDATE_DIE || Mode == DdrMode.ADD)
            {
                parseUpdateDieResponse();
            }
            else if (Mode == DdrMode.FILE_DIE || Mode == DdrMode.UPDATE)
            {
                parseFileDieResponse();
            }
        }

        private void parseUpdateDieResponse()
        {
            string[] lines = Response.Split("\r\n");

            bool dataIsNext = false;
            bool errorIsNext = false;
            string errorMessage = "";

            foreach (string line in lines)
            {
                if (line == "")
                    continue;

                if (line == "[Data]")
                {
                    dataIsNext = true;
                    continue;
                }
                else if (line == "[BEGIN_diERRORS]")
                {
                    dataIsNext = false;
                    errorIsNext = true;
                    continue;
                }
                else if (line == "[END_diERRORS]")
                {
                    errorMessage = errorMessage.Trim();
                    throw new DdrFilerException(errorMessage);
                }

                if (dataIsNext)
                {
                    string[] pieces = line.Split("^");
                    if (pieces.Length == 2)
                    {
                        NewRecordIen = pieces[1];
                        continue;
                    }
                }
                else if (errorIsNext)
                {
                    errorMessage = errorMessage + line + " ";
                }
            }
        }

        public String NewRecordIen
        {
            get;
            private set;
        }

        private void parseFileDieResponse()
        {
            string[] lines = Response.Split("\r\n");

            bool dataIsNext = false;
            bool errorIsNext = false;
            string errorMessage = "";

            foreach (string line in lines)
            {
                if (line == "")
                    continue;

                if (line == "[Data]")
                {
                    dataIsNext = true;
                    continue;
                }
                else if (line == "[BEGIN_diERRORS]")
                {
                    dataIsNext = false;
                    errorIsNext = true;
                    continue;
                }
                else if (line == "[END_diERRORS]")
                {
                    errorMessage = errorMessage.Trim();
                    throw new DdrFilerException(errorMessage);
                }

                if (dataIsNext)
                {
                    continue;
                }
                else if (errorIsNext)
                {
                    errorMessage = errorMessage + line + " ";
                }
            }
        }
    }
}
