﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Vista.RPC.Parameters;

namespace Vista.RPC.Procedures.DDR
{
    public class DdrFindOne : RemoteProcedure
    {
        public DdrFindOne(string file, string lookupValue, string iens = "", string flags = "", string xref = "", string screen = "")
            : base("DDR FIND1")
        {
            if(string.IsNullOrEmpty(file))
                throw new ArgumentNullException(nameof(file));
            if(string.IsNullOrEmpty(lookupValue))
                throw new ArgumentNullException(nameof(lookupValue));

            var dictionary = new Dictionary<string, string> {{"\"FILE\"", file}, {"\"VALUE\"", lookupValue}};

            if(!string.IsNullOrEmpty(iens))
                dictionary.Add("\"IENS\"", iens);
            if(!string.IsNullOrEmpty(flags))
                dictionary.Add("\"FLAGS\"", flags);
            if(!string.IsNullOrEmpty(xref))
                dictionary.Add("\"XREF\"", xref);
            if(!string.IsNullOrEmpty(screen))
                dictionary.Add("\"SCREEN\"", screen);

            AddParameter(new ListParameter(dictionary));
        }

        public enum Result
        {
            NoMatchFound,
            MatchFound,
            Error
        };

        public Result ResultOfQuery()
        {
            if (Response.Trim().Equals("0"))
                return Result.NoMatchFound;
            
            if (Response.Contains("diERRORS") || Response.Trim().Equals("-1"))
                return Result.Error;
            
            return Result.MatchFound;
        }

        /// <summary>
        /// Returns the ien of the record found
        /// </summary>
        /// <returns></returns>
        public string GetResult()
        {
            return Response.Trim();
        }
    }
}
