﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Vista.RPC.Parameters;

namespace Vista.RPC.Procedures.DDR
{
    public class DdrGets : RemoteProcedure
    {
        public DdrGets(String file, String iens, String fields, String optionalFlags = "")
            : base("DDR GETS ENTRY DATA")
        {
            Dictionary<String, String> parameters = new Dictionary<string, string>();
            parameters.Add("\"FILE\"", file);
            parameters.Add("\"IENS\"", iens);
            parameters.Add("\"FIELDS\"", fields);

            if (String.IsNullOrEmpty(optionalFlags))
            {
                optionalFlags = "E";
            }

            parameters.Add("\"FLAGS\"", optionalFlags);

            ListParameter list = new ListParameter(parameters);
            AddParameter(list);

            OptionalFlags = optionalFlags;
        }

        public string OptionalFlags { get; private set; }

        public override void AfterCall()
        {
            RenderResponse();
        }

        private Dictionary<string, FileManFieldValue> mappedValues = null;

        public String GetFieldValue(string fieldNumber, bool externalValue = true)
        {
            if (mappedValues == null)
            {
                return null;
            }

            if (mappedValues.ContainsKey(fieldNumber))
            {

                if (externalValue == true)
                    return mappedValues[fieldNumber].ExternalValue;
                else
                    return mappedValues[fieldNumber].InternalValue;
            }

            return null;
        }

        public FileManFieldValue GetFileManFieldValue(string fieldNumber)
        {
            if (mappedValues.ContainsKey(fieldNumber))
            {
                return mappedValues[fieldNumber];
            }

            return null;
        }

        public Dictionary<string, FileManFieldValue>.KeyCollection GetFieldNumbers()
        {
            if (mappedValues == null)
                return null;
            else
                return mappedValues.Keys;
        }

        private void RenderResponse()
        {
            mappedValues = new Dictionary<string, FileManFieldValue>();
            string[] results = Response.Split("\r\n");

            bool data = false;
            bool inWordField = false;
            string wordField = "";
            StringBuilder builder = null;

            foreach (String line in results)
            {
                if (data == false)
                {
                    if (line == "[Data]")
                    {
                        data = true;
                        continue;
                    }
                }
                else
                {
                    if (String.IsNullOrEmpty(line))
                    {
                        continue;
                    }

                    string[] pieces = line.Split("^");

                    if (inWordField)
                    {
                        // resolve possible null dereference by skipping over the builder
                        if (builder == null)
                        {
                            continue;
                        }
                        if (pieces[0] == "$$END$$")
                        {
                            if (builder[builder.Length - 1] == '\n')
                                builder.Remove(builder.Length - 1, 1);

                            mappedValues.Add(wordField, new FileManFieldValue(builder.ToString()));

                            inWordField = false;
                            builder = null;
                            wordField = null;
                        }
                        else if (builder != null)
                        {
                            builder.Append(line);
                            builder.Append("\n");
                        }

                        continue;
                    }
                    else if (pieces.Length >= 3 && pieces[3] /* word processing field */ == "[WORD PROCESSING]")
                    {
                        inWordField = true;
                        wordField = pieces[2];
                        builder = new StringBuilder();
                        continue;
                    }
                    else if (pieces.Length == 5)
                    {
                        string externalValue = "";
                        string internalValue = "";

                        // if we are retrieving the internal values then return the value from a different piece
                        if (OptionalFlags.ToUpper().Contains("I"))
                        {
                            internalValue = pieces[3];
                        }

                        if (OptionalFlags.ToUpper().Contains("E"))
                        {
                            externalValue = pieces[4];
                        }

                        mappedValues.Add(pieces[2], new FileManFieldValue(externalValue, internalValue));
                        continue;
                    }
                    else if (pieces.Length >= 3)
                    {
                        mappedValues.Add(pieces[2], new FileManFieldValue(""));
                    }
                }
            }
        }

    }
}
