﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Vista.RPC.Parameters;
using Vista.RPC.Exceptions;

namespace Vista.RPC.Procedures
{
    public class RemoteProcedure : IRemoteProcedure
    {
        public const string RPC_VERSION = "1.108";

        public List<IParameter> Parameters
        {
            get;
            protected set; 
        }

        public string RpcName
        {
            get;
            protected set;
        }

        public RemoteProcedure(string rpcName)
        {
            Parameters = new List<IParameter>();
            RpcName = rpcName;
        }

        public void AddParameter(IParameter parameter)
        {
            Parameters.Add(parameter);
        }

        public sealed override string ToProcedure()
        {
            StringBuilder sb = new StringBuilder("5");

            foreach (IParameter p in Parameters)
            {
                if (p is LiteralParameter)
                {
                    LiteralParameter lp = p as LiteralParameter;
                    sb.Append(lp.ToParameter());
                }
                else if (p is ReferenceParameter)
                {
                    ReferenceParameter rp = p as ReferenceParameter;
                    sb.Append(rp.ToParameter());
                }
                else if (p is ListParameter)
                {
                    ListParameter lp = p as ListParameter;
                    sb.Append(lp.ToParameter());
                }
            }

            if (sb.ToString().Equals("5"))
            {
                sb.Append("4f");
            }

            /* build header */
            StringBuilder header = new StringBuilder();
            header.Append("[XWB]11302");
            header.Append(RPC_VERSION.PackString());
            header.Append(RpcName.PackString());

            sb.Insert(0, header.ToString());

            /* append eof */
            sb.Append("\x04");

            return sb.ToString();
        }

        public override void AfterCall()
        {

        }
    }
}
