﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Vista.RPC.Parameters;

namespace Vista.RPC.Procedures.XOBE
{
    public class ElectronicSignatureSetDetails : RemoteProcedure
    {
        /// <summary>
        /// Remote procedures that updates the parameters in VistA. If a parameter is omitted or is an empty string then the
        /// data in VistA is deleted for that specific parameter.
        /// </summary>
        /// <param name="initials"></param>
        /// <param name="signatureBlockPrintedName"></param>
        /// <param name="signatureBlockTitle"></param>
        /// <param name="officePhoneNumber"></param>
        /// <param name="voicePagerNumber"></param>
        /// <param name="digitalPagerNumber"></param>
        public ElectronicSignatureSetDetails(string initials = "", string signatureBlockPrintedName = "", string signatureBlockTitle = "",
            string officePhoneNumber = "", string voicePagerNumber = "", string digitalPagerNumber = "") : base("XOBE ESIG SET DATA")
        {
            var dictionary = new Dictionary<string, string>();
            dictionary.Add("\"initial\"", initials);
            dictionary.Add("\"signature block printed name\"", signatureBlockPrintedName);
            dictionary.Add("\"signature block title\"", signatureBlockTitle);
            dictionary.Add("\"office phone\"", officePhoneNumber);
            dictionary.Add("\"voice pager\"", voicePagerNumber);
            dictionary.Add("\"digital pager\"", digitalPagerNumber);

            var listParameter = new ListParameter(dictionary);

            AddParameter(listParameter);
        }

        /// <summary>
        /// Simple check to see if the remote procedure setup the data successfully in VistA
        /// </summary>
        /// <returns>true if succeded, otherwise false</returns>
        public bool IsSetDetailsSuccessful()
        {
            if(Response.Trim().Equals("1"))
                return true;

            return false;
        }

        public string GetMessage()
        {
            return Response;
        }
    }
}
