﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.InteropServices;
using System.Security;
using System.Text;
using Vista.RPC.Models;
using Vista.RPC.Parameters;

namespace Vista.RPC.Procedures.XUS
{
    /// <summary>
    /// This remote procedure logs into a VistA instance using the given A/V codes.
    /// </summary>
    public class AvCode : RemoteProcedure
    {
        public AvCode(SecureString accessCode, SecureString verifyCode = null) : base("XUS AV CODE")
        {
            if (accessCode == null)
            {
                throw new ArgumentNullException(nameof(accessCode));
            }

            var semicolon = new SecureString();
            semicolon.AppendChar(';');

            var encryptedAvCode = accessCode.Concat(semicolon, verifyCode).ToVistaEncrypt();
            //var encryptedAvCode = encryptedAvCode2.ToVistaEncrypt();
            LiteralParameter p = new LiteralParameter(encryptedAvCode);
            AddParameter(p);
        }

        public AvCode(SecureString autoSignonHandler) : base("XUS AV CODE")
        {
            AddParameter(new LiteralParameter(autoSignonHandler));
        }

        public override void AfterCall()
        {
            var splitResponses = Response.Split("\r\n");

            var loginStatus = new LoginResponse()
            {                
                LoggedInDuz = splitResponses[0],
                LoggedIn = splitResponses[0] != "0",
                VerifyNeedsChanging = splitResponses[2] == "1",
                ErrorMessage = splitResponses[3]
            };

            for (int i = 6; i < splitResponses.Length; i++)
            {
                string line = splitResponses[i].Trim();
                if(!string.IsNullOrEmpty(line))
                    loginStatus.LoginMessage.Add(line);
            }

            LoginResponse = loginStatus;
        }

        public LoginResponse LoginResponse { get; private set; }
    }
}
