﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Vista.RPC.Models;

namespace Vista.RPC.Procedures.XUS
{
    public class DivisionGet : RemoteProcedure
    {
        /// <summary>
        /// This remote procedure returns the list of the user's assigned divisions.
        /// If the user does not have more than one division assigned then HasDivisions will return false.
        /// </summary>
        public DivisionGet() : base("XUS DIVISION GET") {}

        private List<Division> divisions = new List<Division>();
        
        public override void AfterCall()
        {
            divisions = new List<Division>();

            if (Response.Trim().Equals("0"))
                HasDivisions = false;
            else
            {
                HasDivisions = true;

                var strings = Response.Trim().Split("\r\n");
                for (int i = 1; i < strings.Length; i++)
                {
                    var values = strings[i].Split("^");
                    var division = new Division() {Ien = values[0], Name = values[1], StationNumber = values[2]};
                    divisions.Add(division);
                }
            }
        }

        public List<Division> Divisions()
        {
            return divisions;
        }

        public bool HasDivisions
        {
            get; 
            private set;
        }
    }
}
