﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Vista.RPC.Utilities
{
    public class FileManDateTime
    {
        const int YrIdx = 0;
        const int YrLth = 3;
        const int MoIdx = 3;
        const int MoLth = 2;
        const int DyIdx = 5;
        const int DyLth = 2;
        const int DotIdx = 7;
        const int DotLth = 1;
        const int HrIdx = 8;
        const int HrLth = 2;
        const int MnIdx = 10;
        const int MnLth = 2;
        const int ScIdx = 12;
        //const int ScLth = 2;

        public static String GetDatePart(String fileManTimeStamp)
        {
            return PadZeroes(fileManTimeStamp).Substring(YrIdx, YrLth);
        }

        public static String GetTimePart(String fileManTimeStamp)
        {
            return PadZeroes(fileManTimeStamp).Substring(HrIdx);
        }

        public static int GetYear(String fileManTimeStamp)
        {
            return Convert.ToInt32(PadZeroes(fileManTimeStamp).Substring(YrIdx, YrLth)) + 1700;
        }

        public static int GetMonth(String fileManTimeStamp)
        {
            return Convert.ToInt32(PadZeroes(fileManTimeStamp).Substring(MoIdx, MoLth));
        }

        public static int GetDay(String fileManTimeStamp)
        {
            return Convert.ToInt32(PadZeroes(fileManTimeStamp).Substring(DyIdx, DyLth));
        }

        public static int GetHour(String fileManTimeStamp)
        {
            return Convert.ToInt32(PadZeroes(fileManTimeStamp).Substring(HrIdx, HrLth));
        }

        public static int GetMinute(String fileManTimeStamp)
        {
            return Convert.ToInt32(PadZeroes(fileManTimeStamp).Substring(MnIdx, MnLth));
        }

        public static int GetSecond(String fileManTimeStamp)
        {
            return Convert.ToInt32(PadZeroes(fileManTimeStamp).Substring(ScIdx));
        }

        public static bool IsValidFileManTimeStamp(String fileManTimeStamp)
        {
            try
            {
                fileManTimeStamp = PadZeroes(fileManTimeStamp);
                int year = GetYear(fileManTimeStamp);
                if (year < 1900)
                {
                    return false;
                }

                int month = GetMonth(fileManTimeStamp);
                if (month > 12)
                {
                    return false;
                }

                int day = GetDay(fileManTimeStamp);
                DateTime result;
                if (month > 0 && day > 0 && !DateTime.TryParse($"{year}-{month}-{day}", out result))
                {
                    return false;
                }

                if (GetHour(fileManTimeStamp) > 23)
                {
                    return false;
                }

                if (GetMinute(fileManTimeStamp) > 59)
                {
                    return false;
                }

                if (GetSecond(fileManTimeStamp) > 59)
                {
                    return false;
                }
            }
            catch (FormatException e)
            {
                return false;
            }
            catch (OverflowException e)
            {
                return false;
            }
            catch (ArgumentOutOfRangeException e)
            {
                return false;
            }

            return true;
        }

        public static DateTime? ToDateTime(String fileManTimeStamp)
        {
            if (String.IsNullOrEmpty(fileManTimeStamp))
            {
                return null;
            }

            if (fileManTimeStamp.IndexOf("SENSITIVE") != -1)
            {
                return new DateTime();
            }
            
            if (fileManTimeStamp.Equals("TODAY"))
            {
                return DateTime.Now;
            }
                       
//            if (fileManTimeStamp == "")
//            {
//                return new DateTime();
//            }

            try
            {
                string correctFileManTimeStamp = CorrectFileManTimeStamp(fileManTimeStamp);
                return new DateTime(GetYear(correctFileManTimeStamp), GetMonth(correctFileManTimeStamp), GetDay(correctFileManTimeStamp),
                                    GetHour(correctFileManTimeStamp), GetMinute(correctFileManTimeStamp), GetSecond(correctFileManTimeStamp));
            }
            catch (ArgumentOutOfRangeException e)
            {
                // VISTA has some timestamps like NOW000.000000 - WTF are we supposed to do with these - they aren't valid timestamps anyways
                return null;
            }
        }

        public static string ToFileManTimeStamp(DateTime dateTime)
        {            
            string sYear = (dateTime.Year - 1700).ToString();
            string sMonth = (dateTime.Month).ToString().PadLeft(2, '0');
            string sDay = (dateTime.Day).ToString().PadLeft(2, '0');
            string result = sYear + sMonth + sDay + ".";

            string sHour = (dateTime.Hour).ToString().PadLeft(2, '0');
            string sMinutes = (dateTime.Minute).ToString().PadLeft(2, '0');
            string sSeconds = (dateTime.Second).ToString().PadLeft(2, '0');
            result += sHour + sMinutes + sSeconds;
            
            return result;
        }

        private static string CorrectFileManTimeStamp(String fileManTimeStamp)
        {
            if (fileManTimeStamp == "*SENSITIVE*")
            {
                return fileManTimeStamp;
            }
            fileManTimeStamp = PadZeroes(fileManTimeStamp);
            int year = GetYear(fileManTimeStamp);
            if (year < 1900)
            {
                return "";
            }
            int month = GetMonth(fileManTimeStamp);
            if (month == -1 || month > 12)
            {
                fileManTimeStamp = fileManTimeStamp.Substring(YrIdx, YrLth) + "00" + fileManTimeStamp.Substring(DyIdx);
                month = 0;
            }
            int day = GetDay(fileManTimeStamp);
            DateTime result;
            if (day == -1 || !DateTime.TryParse($"{year}-{month}-{day}", out result))
            {
                fileManTimeStamp = fileManTimeStamp.Substring(YrIdx, YrLth + MoLth) + "00" + fileManTimeStamp.Substring(DotIdx);
                day = 0;
            }
            int hour = GetHour(fileManTimeStamp);
            if (hour == -1 || hour > 24) // SMW believe it or not I found one with timestamp of 24
            {
                fileManTimeStamp = fileManTimeStamp.Substring(YrIdx, YrLth + MoLth + DyLth + DotLth) + "00" + fileManTimeStamp.Substring(MnIdx);
            }
            int minute = GetMinute(fileManTimeStamp);
            if (minute == -1 || minute > 59)
            {
                fileManTimeStamp = fileManTimeStamp.Substring(YrIdx, YrLth + MoLth + DyLth + DotLth + HrLth) + "00" + fileManTimeStamp.Substring(ScIdx);
            }
            int second = GetSecond(fileManTimeStamp);
            if (second == -1 || second > 59)
            {
                fileManTimeStamp = fileManTimeStamp.Substring(YrIdx, YrLth + MoLth + DyLth + DotLth + HrLth + MnLth) + "00";
            }
            return fileManTimeStamp;
        }

        private static String PadZeroes(String fileManTimeStamp)
        {
            if (fileManTimeStamp == "*SENSITIVE*")
            {
                return fileManTimeStamp;
            }

            if (fileManTimeStamp.IndexOf("@") != -1)
            {
                fileManTimeStamp = fileManTimeStamp.Replace('@', '.');
            }

            if (fileManTimeStamp.IndexOf(".") != -1)
            {
                string[] parts = fileManTimeStamp.Split("."); 
                fileManTimeStamp = parts[0] + "0000000".Substring(0, 7 - parts[0].Length) + '.' +
                     parts[1] + "000000".Substring(0, 6 - parts[1].Length);
            }
            else
            {
                fileManTimeStamp = fileManTimeStamp + "0000000".Substring(0, 7 - fileManTimeStamp.Length) + ".000000";
            }

            return fileManTimeStamp;
        }

    }
}
