﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Vista.RPC.Utilities
{
    public class MumpsDateTime
    {
        public static DateTime EPOCH_DATE = DateTime.Parse("12/31/1840");

        /// <summary>
        /// Get the mumps date and time (using $HOROLOG) as of now.
        /// More information about $HOROLOG available at https://docs.intersystems.com/irislatest/csp/docbook/DocBook.UI.Page.cls?KEY=RCOS_vhorolog
        /// </summary>
        /// <returns>The mumps date and time</returns>
        public static string Now()
        {
            var dateTimeNow = DateTime.Now;
            return Get(dateTimeNow);
        }

        /// <summary>
        /// Give a specific date and time return the mumps date and time (using $HOROLOG).
        /// More information about $HOROLOG available at https://docs.intersystems.com/irislatest/csp/docbook/DocBook.UI.Page.cls?KEY=RCOS_vhorolog
        /// </summary>
        /// <returns>The mumps date and time</returns>
        public static string Get(DateTime dateTime)
        {
            if (DateTime.Compare(dateTime, EPOCH_DATE) <= 0)
            {
                throw new ArgumentException("Given date time cannot be less than " + EPOCH_DATE);
            }

            var numberOfDays = dateTime.Subtract(EPOCH_DATE);
            return numberOfDays.Days.ToString() + "," + (int) dateTime.TimeOfDay.TotalSeconds;
        }
    }
}
