﻿-- =============================================
-- Description:	Identifies true/false if the user is a national user
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
-- -----------     ---------     ----------------------------
-- Ken Baker     03/22/2012	     Created
-- =============================================
CREATE FUNCTION [dbo].[ufnIsNationalUser]
(
	@userId int,
	@applicationIds tinyint
)
RETURNS bit
AS
BEGIN
	DECLARE @isNationalUser bit,
			@accessLevelId tinyint

	SET @isNationalUser = 0;
	SELECT @accessLevelId = dbo.ufnGetAccessLevelConstant('National');
	
	IF @userId Is Null Or @userId = 0
		BEGIN
			SET @isNationalUser = 1;
		END
	ELSE
		BEGIN
			IF EXISTS (SELECT UserID 
					    FROM UserRoles
						WHERE UserID = @userId 
						AND AccessStatus = 'APPROVED' 
						AND AccessLevelID = @accessLevelId
						AND (ApplicationID In(SELECT [Value] FROM ufnSplit(',', @applicationIds)) OR @applicationIds IS NULL))
				BEGIN
					SET @isNationalUser = 1;
				END
		END
	RETURN @isNationalUser;
END
GO