﻿-- =============================================
-- Description:	Identifies true/false if user is permitted to see PII for specified station.
-- =============================================
CREATE PROCEDURE [dbo].[uspGetShowPIIUserStation] (
	@userId int,
	@applicationIds varchar(max),
	@stationIds varchar(max)
)
AS
BEGIN
	DECLARE @showPII bit;
	DECLARE @userRoleTable TABLE
			(
				ID int,
				ApplicationID smallint,
				RegionID tinyint,
				VisnID tinyint,
				StationID smallint,
				StationName varchar(250),
				RoleID tinyint, 
				AccessLevelID tinyint,
				AccessStatus varchar(50),
				ShowPII bit,
				UserID int
			);

	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRY
		--If @stationIds should use zero (null station placeholder), 
		--null that out so can get a proper answer
		IF @stationIds = '0' 
			BEGIN
				SET @stationIds = Null
			END
		INSERT INTO @userRoleTable (ID, ApplicationID, VisnID, StationID, RoleID, AccessStatus, AccessLevelID, ShowPII, UserID)
		EXEC uspGetUserStationRoles @userId, @applicationIds;

		SELECT TOP 1 @showPII = ShowPII
		FROM @userRoleTable
		WHERE (StationID In(SELECT [Value] FROM ufnSplit(',', @stationIds)) OR @stationIds IS NULL) 
		AND (ApplicationID In(SELECT [Value] FROM ufnSplit(',', @applicationIds)) OR @applicationIds IS NULL) 
		AND ShowPII = 1
		AND AccessStatus = 'APPROVED';

		IF @showPII Is Null 
			BEGIN
				SET @showPII = 0
			END

		SELECT @showPII AS ShowPII;
	END TRY

	BEGIN CATCH
		PRINT 'There was an error getting show PII for user/station' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END
GO