﻿
-- =============================================
-- Description:	Returns user's permitted list of stations
-- =============================================
Create PROCEDURE [dbo].uspGetUserStationsByUsername
	-- Add the parameters for the stored procedure here
	@userName varchar(50),
	@applicationIds varchar(max)
AS
	DECLARE @ACCESS_LEVEL_REGION tinyint,
			@ACCESS_LEVEL_VISN tinyint,
			@ACCESS_LEVEL_STATION tinyint,
    		@ACCESS_STATUS_APPROVED varchar(10),
			@isNationalUser bit,
			@minAppID tinyint;

	DECLARE @resultsTable table
	(
		ApplicationID tinyint,
		VisnID tinyint,
		StationID smallint,
		ParentStationID smallint,
		Station3N varchar(10),
		Station6A varchar(10),
		StationDisplayName varchar(100),
		StationName varchar(100),
		IsParent bit,
		Inactive bit
	);

	DECLARE @applicationsTable table
	(
		ApplicationID tinyint
	);

BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRY
		BEGIN
			--Set necessary variables
			SET @ACCESS_STATUS_APPROVED = 'APPROVED';
			SELECT @ACCESS_LEVEL_REGION = dbo.ufnGetAccessLevelConstant('Region');
			SELECT @ACCESS_LEVEL_VISN = dbo.ufnGetAccessLevelConstant('Visn');
			SELECT @ACCESS_LEVEL_STATION = dbo.ufnGetAccessLevelConstant('Station');
			--will need to start the wrapper here for all permutations of appID--
			--build a table of various appId's--
			IF @applicationIds IS NULL
				BEGIN				
					INSERT INTO @applicationsTable (ApplicationID)
					SELECT ApplicationID FROM Applications;
				END
			ELSE
				BEGIN
					INSERT INTO @applicationsTable (ApplicationID)
					SELECT [Value] FROM ufnSplit(',', @applicationIds);
				END
			--Set the min rowId to start the while loop
			SELECT @minAppID = MIN(ApplicationID)
			FROM @applicationsTable;

		WHILE @minAppID IS NOT NULL 
			BEGIN
				SELECT @isNationalUser = dbo.ufnIsNationalUserName(@userName, @minAppID);

				--If is a national user or no user id is returned, then return all
				IF @userName Is Null OR @userName = ' ' OR @isNationalUser = 1
					BEGIN
						WITH LookupTable (VisnID, StationID, ParentStationID, Station3N, Station6A, 
							StationDisplayName, StationName, IsParent, Inactive) AS
							(
							SELECT DISTINCT t.VisnID, t.StationID, t.ParentStationID, t.Station3N, t.Station6A,
								'V' + VisnCode + ': ' + t.Station6A + ': ' + t.StationName, 
								t.StationName, t.ParentStation, t.Inactive
								FROM Stations t 
								INNER JOIN Visns ON t.VisnID = Visns.VisnID
						)
					INSERT INTO @resultsTable (ApplicationID, VisnID, StationID, ParentStationID, 
						Station3N, Station6A, StationDisplayName, StationName, IsParent, Inactive)
					SELECT @minAppID, VisnID, StationID, ParentStationID, 
						Station3N, Station6A, StationDisplayName, StationName, IsParent, Inactive
						FROM LookupTable;					
					END
				ELSE
					BEGIN
						WITH LookupTable (VisnID, StationID, ParentStationID, Station3N, Station6A, 
							StationDisplayName, StationName, IsParent, Inactive) AS
							(
							--check Region permissions
							SELECT DISTINCT t.VisnID, t.StationID, t.ParentStationID, t.Station3N, t.Station6A,
									'V' + VisnCode + ': ' + t.Station6A + ': ' + t.StationName, 
									t.StationName, t.ParentStation, t.Inactive
								FROM Stations t 
								INNER JOIN Visns ON t.VisnID = Visns.VisnID
								WHERE EXISTS(SELECT DISTINCT 1 FROM UserRoles 
								INNER JOIN Regions ON Regions.RegionID = UserRoles.RegionID
								INNER JOIN Users ON UserRoles.UserID = Users.UserID
								WHERE UserName = @userName 
								AND ApplicationID = @minAppID
								AND AccessLevelID = @ACCESS_LEVEL_REGION
								AND AccessStatus = @ACCESS_STATUS_APPROVED)

							--check Visn permissions
							UNION SELECT DISTINCT t.VisnID, t.StationID, t.ParentStationID, t.Station3N, t.Station6A,
									'V' + VisnCode + ': ' + t.Station6A + ': ' + t.StationName, 
									t.StationName, t.ParentStation, t.Inactive
								FROM Stations t 
								INNER JOIN Visns ON t.VisnID = Visns.VisnID
								INNER JOIN UserRoles ON t.VisnID = UserRoles.VisnID
								INNER JOIN Users ON UserRoles.UserID = Users.UserID
								WHERE UserName = @userName 
								AND ApplicationID = @minAppID
								AND AccessLevelID = @ACCESS_LEVEL_VISN
								AND AccessStatus = @ACCESS_STATUS_APPROVED

							--check Station permissions
							UNION SELECT DISTINCT t.VisnID, t.StationID, t.ParentStationID, t.Station3N, t.Station6A,
									'V' + VisnCode + ': ' + t.Station6A + ': ' + t.StationName, 
									t.StationName, t.ParentStation, t.Inactive
								FROM Stations t
								INNER JOIN Visns ON t.VisnID = Visns.VisnID
								INNER JOIN UserRoles ON t.StationID = UserRoles.StationID
								INNER JOIN Users ON UserRoles.UserID = Users.UserID
								WHERE UserName = @userName 
								AND ApplicationID = @minAppID
								AND AccessLevelID = @ACCESS_LEVEL_STATION
								AND AccessStatus = @ACCESS_STATUS_APPROVED
						)

						--same insertion to appresults
						INSERT INTO @resultsTable (ApplicationID, VisnID, StationID, ParentStationID, 
							Station3N, Station6A, StationDisplayName, StationName, IsParent, Inactive)
						SELECT @minAppID, VisnID, StationID, ParentStationID, 
							Station3N, Station6A, StationDisplayName, StationName, IsParent, Inactive
							FROM LookupTable	;
					END
	
				--Iterate at the end of the loop to the next RowID
				SELECT @minAppID = MIN(ApplicationID) 
				FROM @applicationsTable 
				WHERE ApplicationID > @minAppID ;
			END
		END
		
		--Return results
		SELECT DISTINCT CAST(ROW_NUMBER() OVER(ORDER BY StationID) AS int) AS 'RowID'
			, ApplicationID
			, VisnID
			, StationID
			, ParentStationID
			, Station3N
			, Station6A
			, StationDisplayName
			, StationName
			, IsParent
			, Inactive		
		FROM @resultsTable
		ORDER BY ApplicationID, VisnID, Station3N, Station6A;
	END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the user stations' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END

GO


