﻿-- =============================================
-- Description:	Returns user's permitted list of Visns
-- =============================================
CREATE PROCEDURE [dbo].[uspGetUserVisns]
	-- Add the parameters for the stored procedure here
	@userId int,
	@applicationIds varchar(max)
AS
DECLARE @ACCESS_LEVEL_REGION tinyint,
	    @ACCESS_LEVEL_VISN tinyint,
	    @ACCESS_LEVEL_STATION tinyint,
    	@ACCESS_STATUS_APPROVED varchar(10),
		@isNationalUser bit,
		@minAppID tinyint;


	DECLARE @resultsTable table
	(
		ApplicationID tinyint,
		RegionID tinyint,
		AltRegionID tinyint,
		VisnID tinyint,
		VisnCode varchar(10),
		VisnDisplayName varchar(50),
		VisnName varchar(100),
		Inactive bit
	);

	DECLARE @applicationsTable table
	(
		ApplicationID tinyint
	);

BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRY
		BEGIN
			--Set necessary variables
			SET @ACCESS_STATUS_APPROVED = 'APPROVED';
			SELECT @ACCESS_LEVEL_REGION = dbo.ufnGetAccessLevelConstant('Region');
			SELECT @ACCESS_LEVEL_VISN = dbo.ufnGetAccessLevelConstant('Visn');
			SELECT @ACCESS_LEVEL_STATION = dbo.ufnGetAccessLevelConstant('Station');

			--will need to start the wrapper here for all permutations of appID--
			--build a table of various appId's--
			IF @applicationIds IS NULL
				BEGIN				
					INSERT INTO @applicationsTable (ApplicationID)
					SELECT ApplicationID FROM Applications;
				END
			ELSE
				BEGIN
					INSERT INTO @applicationsTable (ApplicationID)
					SELECT [Value] FROM ufnSplit(',', @applicationIds);
			END

			--Set the min rowId to start the while loop
			SELECT @minAppID = MIN(ApplicationID)
			FROM @applicationsTable;

			WHILE @minAppID IS NOT NULL 
				BEGIN
					SELECT @isNationalUser = dbo.ufnIsNationalUser(@userId, @applicationIds)

					--If is a national user or no user id is returned, then return all
					IF @userId Is Null OR @userId = 0 OR @isNationalUser = 1
						BEGIN
							WITH LookupTable (RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName, Inactive) AS
								(
								SELECT DISTINCT t.RegionID, t.AltRegionID, t.VisnID, t.VisnCode, 'VISN ' + t.VisnCode, t.VisnName, t.Inactive
									FROM Visns t	
							)
							INSERT INTO @resultsTable (ApplicationID, RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName, Inactive)
							SELECT @minAppID, RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName, Inactive
								FROM LookupTable;
								--ORDER BY VisnID, VisnName	
						END
					ELSE
						BEGIN
							WITH LookupTable (RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName, Inactive) AS
								(
								--check Region permissions
								SELECT DISTINCT t.RegionID, t.AltRegionID, t.VisnID, t.VisnCode, 'VISN ' + t.VisnCode, t.VisnName, t.Inactive
									FROM Visns t INNER JOIN UserRoles ON t.RegionID = UserRoles.RegionID
									WHERE UserID = @userId 
									AND ApplicationID = @applicationIds
									AND AccessLevelID = @ACCESS_LEVEL_REGION
									AND AccessStatus = @ACCESS_STATUS_APPROVED
								--check Visn permissions
								UNION SELECT DISTINCT t.RegionID, t.AltRegionID, t.VisnID, t.VisnCode, 'VISN ' + t.VisnCode, t.VisnName, t.Inactive
									FROM Visns t INNER JOIN UserRoles ON t.VisnID = UserRoles.VisnID
									WHERE UserID = @userId 
									AND ApplicationID = @applicationIds
									AND AccessLevelID = @ACCESS_LEVEL_VISN
									AND AccessStatus = @ACCESS_STATUS_APPROVED
								--check Station permissions
								UNION SELECT DISTINCT t.RegionID, t.AltRegionID, t.VisnID, t.VisnCode, 'VISN ' + t.VisnCode, t.VisnName, t.Inactive
									FROM Visns t
									WHERE EXISTS (SELECT DISTINCT f.VisnID FROM Stations f
										INNER JOIN UserRoles ON f.StationID = UserRoles.StationID
										WHERE f.VisnID = t.VisnID
										AND UserID = @userId 
										AND ApplicationID = @applicationIds
										AND AccessLevelID = @ACCESS_LEVEL_STATION
										AND AccessStatus = @ACCESS_STATUS_APPROVED)
							)
							--same insertion to appresults
							INSERT INTO @resultsTable (ApplicationID, RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName, Inactive)
								SELECT @minAppID, RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName, Inactive
									FROM LookupTable;
									--ORDER BY VisnID, VisnName
						END

					--Iterate at the end of the loop to the next RowID
					SELECT @minAppID = MIN(ApplicationID) 
					FROM @applicationsTable 
					WHERE ApplicationID > @minAppID ;
			END
		END
		--Return results
		SELECT DISTINCT	CAST(ROW_NUMBER() OVER(ORDER BY VisnID) AS int) AS 'RowID'
			, ApplicationID
			, RegionID
			, AltRegionID
			, VisnID
			, VisnCode
			, VisnDisplayName
			, VisnName
			, Inactive 
		FROM @resultsTable
		ORDER BY ApplicationID, VisnID, VisnName;

	END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the user VISNs' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END
GO