﻿-- =============================================
-- Description:	Returns list of VISNs.
--
-- Maintenance Log:
--
-- Update By     Update Date     Description
-- -----------     ---------     ----------------------------
-- =============================================
CREATE PROCEDURE [dbo].[uspGetVisns]
	@regionIds varchar(max)
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRY
		SELECT DISTINCT Visns.VisnID, Visns.VisnCode, 'V' + CAST(Visns.VISNCode AS varchar)  AS VisnLabel 
		FROM Stations
		LEFT OUTER JOIN Visns ON Visns.VisnID = Stations.VisnID
		LEFT OUTER JOIN Regions ON Regions.RegionID = Visns.RegionID
		WHERE (Regions.RegionCode In(SELECT [value] FROM ufnSplit(',', @regionIds)) OR @regionIds IS NULL)
		UNION SELECT NULL AS VisnID, NULL AS VisnCode, '[All]' AS VisnLabel
		ORDER BY Visns.VisnID ASC
	END TRY

	BEGIN CATCH
		PRINT 'There was an error getting VISNs' + CHAR(13)
		SELECT * FROM dbo.ufnGetErrorInfo()
		EXEC uspRaiseErrorInfo
	END CATCH
END
GO

