﻿-- =============================================
-- Description:	Returns list of parent stations with null handler; ties into the reporting.
-- =============================================
CREATE PROCEDURE [dbo].[uspRptGetUserParentStationsListWithNullHandler]
	@visnIds varchar(max), 
	@userId int,
	@applicationIds varchar(max)
AS
	DECLARE @resultsTable table
	(
		RowID int,
		ApplicationID tinyint,
		VisnID tinyint,
		StationID smallint,
		ParentStationID smallint,
		Station3N varchar(10),
		Station6A varchar(10),
		StationDisplayName varchar(100),
		StationName varchar(100),
		IsParent bit,
		Inactive bit
	);
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	BEGIN TRY
		INSERT INTO @resultsTable (RowID, ApplicationID, VisnID, StationID, ParentStationID, Station3N, Station6A
				, StationDisplayName, StationName, IsParent, Inactive)
		EXEC uspGetUserParentStations @userId, @applicationIds;

		SELECT DISTINCT VisnID, StationID, ParentStationID, Station3N, Station6A, 
			StationDisplayName, StationName, IsParent, Inactive
		FROM (
			SELECT 0 AS VisnID, 0 as StationID, 0 AS ParentStationID, NULL As Station3N, NULL As Station6A,
				'[Null Values]' AS StationDisplayName, '[Null Values]' AS StationName, 1 AS IsParent, 0 AS Inactive
			UNION 
			SELECT DISTINCT VisnID, StationID, ParentStationID, Station3N, Station6A, 
				StationDisplayName, StationName, IsParent, Inactive
			FROM @resultsTable
			WHERE (VisnID In(SELECT [Value] FROM ufnSplit(',', @visnIds)) OR @visnIds IS NULL)
			--UNION SELECT NULL AS RowID, 0 AS ApplicationID, 0 AS VisnID
			--, NULL AS StationID, NULL AS Station3N, NULL AS Station6A
			--, '[All]' AS StationDisplayName, '[All]' AS StationName, 1 AS IsParent, 0 AS Inactive
		) AS SubQ
		ORDER BY VisnID, Station3N, StationDisplayName;
	END TRY
	BEGIN CATCH
		PRINT 'There was an while getting user parent station list with null handler' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END
GO
