﻿-- =============================================
-- Description:	Returns list of Visns with a null handler that ties into the reporting (alternate regions).
-- =============================================
CREATE PROCEDURE [dbo].[uspRptGetUserVisnsAltRegionsListWithNullHandler]
	@regionIds varchar(max),
	@userId int,
	@applicationIds varchar(max)
AS
	DECLARE @resultsTable table
	(
		RowID int,
		ApplicationID tinyint,
		RegionID tinyint,
		AltRegionID tinyint,
		VisnID tinyint,
		VisnCode varchar(10),
		VisnDisplayName varchar(50),
		VisnName varchar(100),
		Inactive bit
	);
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	BEGIN TRY

		INSERT INTO @resultsTable (RowID, ApplicationID, RegionID, AltRegionID, VisnID, VisnCode, 
			VisnDisplayName, VisnName, Inactive)
		EXEC uspGetUserVisns @userId, @applicationIds;

		 SELECT RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName
		 FROM (
			   SELECT NULL as RegionID, NULL AS AltRegionID, 0 as VisnID, '0' AS VisnCode,
				'[Null Values]' AS VisnDisplayName, '[Null Values]' AS VisnName
                UNION 
				SELECT DISTINCT RegionID, AltRegionID, VisnID, VisnCode, VisnDisplayName, VisnName
					FROM @resultsTable
					WHERE (AltRegionID In(SELECT [Value] FROM ufnSplit(',', @regionIds)) OR @regionIds IS NULL)
					--UNION SELECT Null AS RowID, 0 AS RegionID, NULL AS VisnID, NULL AS VisnCode, 
					--'[All]' AS 'VisnDisplayName', '[All]' AS VisnName
					) AS SubQ
					ORDER BY   VisnID, VisnDisplayName;
	END TRY
	BEGIN CATCH
		PRINT 'There was an while getting user VISN reporting (alt regions)' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END
GO
