﻿
-- =============================================
-- Description:	Returns detail data for from Key Replication logs for reporting.
-- =============================================
CREATE PROCEDURE [dbo].[uspRptReplicationLogServiceSection]
	-- Add the parameters for the stored procedure here
	@VistaService varchar(max),
	@LogType varchar(max),
	@RemoteStation varchar(max),
	@StartDate datetime2 (7),
	@EndDate datetime2 (7)
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	BEGIN TRY
	        
	    --Conditional Check 
        --If End date is less than begin date, set end date = begin date 
        IF @EndDate  < @StartDate 
                BEGIN 
                        SET @EndDate = @StartDate 
         END


SELECT 
 VU.StationID as 'UserStation'
,STb.Station3N as 'Station3NVU'
,STb.StationName as 'StationNameVU'
,STb.DisplayName as 'DisplayNameVU'
,V2.VisnCode as 'VisnCodeVU'
,V2.VisnName as 'VisnNameVU'
,VU.VistaUserFullName
,VU.VistaService
,RL.ReplicationID
,RL.ReplicationLogID
,R.ReplicationDate
,R.StationID as 'RemoteStation'
,STa.Station3N as 'Station3NR'
,STa.StationName as 'StationNameR'
,STa.DisplayName as 'DisplayNameR'
,V1.VisnCode as 'VisnCodeR'
,V1.VisnName as 'VisnNameR'
,R.VistaUserID
,RL.LogDate
,RL.LogType
,RL.ItemTypeID
,RL.ItemName
,RL.ErrorOccurred
,RL.LogMessage
,RL.LogDetail


 FROM ReplicationLogEvents RL

  INNER JOIN ReplicationLogs R
  ON RL.ReplicationID = R.ReplicationID 

  INNER JOIN dbo.VistaUsers VU
  ON R.VistaUserID = VU.VistaUserID

  LEFT JOIN dbo.Stations STa
  ON R.StationID  = STa.StationID

  LEFT JOIN dbo.Visns V1
  ON STa.VisnId = V1.VisnId

  LEFT JOIN dbo.Stations STb
  ON VU.StationID  = STb.StationID

  LEFT JOIN dbo.Visns V2
  ON STb.VisnId = V2.VisnId


  

  WHERE 
  (VistaService In(SELECT [Value] FROM ufnSplit(',', @VistaService)) OR @VistaService IS NULL)
  AND (LogType In(SELECT [Value] FROM ufnSplit(',', @LogType)) OR @LogType IS NULL)
  AND (R.StationID In(SELECT [Value] FROM ufnSplit(',', @RemoteStation)) OR @RemoteStation IS NULL)
  AND ReplicationDate >= @startDate AND ReplicationDate < DATEADD(day, 1, @endDate);
  
END TRY





	BEGIN CATCH
		PRINT 'There was an error processing the details replication logs report' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END


GO


