﻿-- =============================================
-- Description:	Returns detail data for from Key Replication logs for reporting.
-- =============================================
CREATE PROCEDURE [dbo].[uspRptReplicationLogServiceSectionSecUsername]
	-- Add the parameters for the stored procedure here
	@VistaService varchar(max),
	@LogType varchar(max),
	@RemoteStation varchar(max),
	@userName varchar(50)
	--@StartDate datetime2 (7),
	--@EndDate datetime2 (7)
AS
	DECLARE @stationsTable TABLE
	(
		RowID int,
		ApplicationID tinyint,
		VisnID tinyint /*INDEX IX_uCLDV NONCLUSTERED*/,
		StationID smallint,
		ParentStationID smallint /*INDEX IX_uCLDS NONCLUSTERED*/,
		Station3N varchar(10),
		Station6A varchar(10),
		StationDisplayName varchar(100),
		StationName varchar(100),
		IsParent bit,
		Inactive bit,
			INDEX IX_uCLDCOMP CLUSTERED(VisnID, ParentStationID)
	);

BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	BEGIN TRY
	        
	    --Conditional Check 
        --If End date is less than begin date, set end date = begin date 
        --IF @EndDate  < @StartDate 
        --        BEGIN 
        --                SET @EndDate = @StartDate 
         --END

		--populate what stations the user has permission to see
		INSERT INTO @stationsTable (RowID, ApplicationID, VisnID, StationID, ParentStationID, Station3N, Station6A
				, StationDisplayName, StationName, IsParent, Inactive)
		EXEC uspGetUserStationsByUsername @userName, null;

		--conditional check, drop temp table if exists--
		IF object_Id ('tempdb..##VramTable') is not null
		DROP table ##VramTable
		--put data needed into temp table--
		SELECT 
			 VU.StationID as 'UserStation',STb.Station3N as 'Station3NVU',STb.StationName as 'StationNameVU',STb.DisplayName as 'DisplayNameVU'
			,V2.VisnCode as 'VisnCodeVU',V2.VisnName as 'VisnNameVU',VU.VistaUserFullName,VU.VistaService,RL.ReplicationID,RL.ReplicationLogID
			,R.ReplicationDate,R.StationID as 'RemoteStation',STa.Station3N as 'Station3NR',STa.StationName as 'StationNameR'
			,V1.VisnCode as 'VisnCodeR',V1.VisnName as 'VisnNameR',R.VistaUserID,RL.LogDate,RL.LogType,RL.ItemTypeID,RL.ItemName
			,RL.ErrorOccurred,RL.LogMessage,RL.LogDetail
		INTO ##VramTable
		FROM ReplicationLogEvents RL
			INNER JOIN ReplicationLogs R
			ON RL.ReplicationID = R.ReplicationID 
			INNER JOIN dbo.VistaUsers VU
			ON R.VistaUserID = VU.VistaUserID
			LEFT JOIN @stationsTable STa
			ON R.StationID  = STa.StationID
			LEFT JOIN dbo.Visns V1
			ON STa.VisnId = V1.VisnId
			LEFT JOIN dbo.Stations STb
			ON VU.StationID  = STb.StationID
			LEFT JOIN dbo.Visns V2
			ON STb.VisnId = V2.VisnId;

		--select everything from the temp table, performing pulling only the MAX replicationdate since the customer did not want 
		--to see all replications
		SELECT a.*
		FROM ##VramTable a
		INNER JOIN (
		SELECT Station3NVU, VistaService, VistaUserFullName, Station3NR   , max (ReplicationDate) as 'RepDate'
		FROM ##VramTable
		GROUP BY  Station3NVU, VistaService, VistaUserFullName, Station3NR
			) b
			ON a.Station3NVU = b.Station3NVU
			AND a.VistaService = b.VistaService
			AND a.VistaUserFullName = b.VistaUserFullName
			AND a.Station3NR = b.Station3NR
			AND a.ReplicationDAte = b.RepDate
		WHERE (a.VistaService In(SELECT [Value] FROM ufnSplit(',', @VistaService)) OR @VistaService IS NULL)
		  AND (a.LogType In(SELECT [Value] FROM ufnSplit(',', @LogType)) OR @LogType IS NULL)
		  AND (a.Station3NR In(SELECT [Value] FROM ufnSplit(',', @RemoteStation)) OR @RemoteStation IS NULL)
		--AND  ReplicationDate Between @StartDate AND @EndDate  ---- Not needed anymore for actionable records
		;
	END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the IT Error Worklist by Service Section report' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
END




GO


