﻿
-- =============================================
-- Description:      Returns user details.
-- =============================================
CREATE PROCEDURE [dbo].[uspRptUserList]
       -- Add the parameters for the stored procedure here
	@ADDomains varchar(max),
	@accessStatuses varchar(max),
	@userId int

AS
	DECLARE @stationsTable TABLE
	(
		RowID int,
		ApplicationID tinyint,
		VisnID tinyint,
		StationID smallint,
		ParentStationID smallint,
		Station3N varchar(10),
		Station6A varchar(10),
		StationDisplayName varchar(100),
		StationName varchar(100),
		IsParent bit,
		Inactive bit
	);
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

       BEGIN TRY
		--populate what stations the user has permission to see
		INSERT INTO @stationsTable (RowID, ApplicationID, VisnID, StationID, ParentStationID, Station3N, Station6A
				, StationDisplayName, StationName, IsParent, Inactive)
		EXEC uspGetUserStations @userId, null

			SELECT 
				UserID
				, ADDomain
				, FirstName
				, LastName
				, UserName
				, EmailAddress
				, PhoneNumber
				, PhoneExtension
				, SupervisorName
				, SupervisorPhoneNumber
				, SupervisorEmailAddress
				, CreatedByUserName
				, UpdatedByUserName
				, DateCreated
				, DateUpdated
				, DateLastLogin
				, Inactive
				, DateInactive
				, CompletedRequestForm
			FROM seclyr.Users
			WHERE (ADDomain In(SELECT [Value] FROM ufnSplit(',', @ADDomains)) OR @ADDomains Is Null)
			AND EXISTS (SELECT 1 FROM UserRoles
				WHERE UserRoles.UserID = Users.UserID
				AND (AccessStatus In(SELECT [Value] FROM ufnSplit(',', @accessStatuses)) OR @accessStatuses Is Null)
				)
			ORDER BY LastName, FirstName;
       END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the user details report' + CHAR(13) ;
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH
	
	DECLARE @webMessage varchar(400)
	SET @webMessage= 'AD Domains: ' + 
		CASE WHEN LEN(@ADDomains) > 0 THEN @ADDomains ELSE 'None specified' END
		 + ', Access Statuses: ' + 
		 CASE WHEN LEN(@accessStatuses) > 0 THEN @accessStatuses ELSE 'None specified' END

	EXEC uspSaveRptParameters @userId, 'uspRptUserList', @webMessage;

END