﻿
-- =============================================
-- Description:      Returns user role details.
-- =============================================
CREATE PROCEDURE [dbo].uspRptUserRoles
       -- Add the parameters for the stored procedure here

	@ADDomains varchar(max),
	@regionIds varchar(max),
	--@applicationIds varchar(max),
	@userId int

AS
DECLARE @stationsTable TABLE
		(
			ID int,
			VisnID varchar (100),
			ParentStationID varchar(100),
			StationID varchar (100),
			StationName varchar(max),
			Inactive bit,
			IsParent bit,
			ApplicationID tinyint
		);

BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

       BEGIN TRY
	   		--populate what stations the user has permission to see
		--INSERT INTO @stationsTable (ID, VisnID, StationID, StationName, ParentStationID, Inactive, IsParent, ApplicationID)
		--EXEC uspGetUserParentStationLookups @userId, NULL

		IF NULLIF(@ADDomains, '') IS NOT NULL
			BEGIN 
			   SELECT ADDomain, LastName, FirstName, RoleName, AccessLevelName, UserRoles.ApplicationID, ApplicationName, 
			   UserRoles.RegionID, AssignedRegions.RegionCode,
			   UserRoles.VisnID, AssignedVisns.VisnCode, UserRoles.StationID, Stations.Station3N, Stations.StationName
			   AccessStatus, PointOfContact, ShowPII, Comments, UserName

				FROM UserRoles
					INNER JOIN Users ON Users.UserID = UserRoles.UserID
					INNER JOIN Roles ON Roles.RoleID = UserRoles.RoleID
					INNER JOIN AccessLevels ON AccessLevels.AccessLevelID = UserRoles.AccessLevelID
					INNER JOIN Applications ON Applications.ApplicationID = UserRoles.ApplicationID
					LEFT OUTER JOIN Stations ON UserRoles.StationID = Stations.StationID
					LEFT OUTER JOIN Visns AssignedVisns ON UserRoles.VisnID = AssignedVisns.VisnID
					LEFT OUTER JOIN Regions AssignedRegions ON  UserRoles.RegionID = AssignedRegions.RegionID
				WHERE ADDomain In(SELECT [Value] FROM ufnSplit(',', @ADDomains))
				ORDER BY ADDomain, UserRoles.VisnID, UserRoles.StationID, LastName, FirstName		;	
			END
		ELSE --IF NULLIF(@regionIds, '') IS NOT NULL
			BEGIN
			   SELECT ADDomain, LastName, FirstName, RoleName, AccessLevelName, ApplicationName, RegionID, VisnID, StationID, AccessStatus, PointOfContact, ShowPII, Comments, UserName

				FROM UserRoles
					INNER JOIN Users ON Users.UserID = UserRoles.UserID
					INNER JOIN Roles ON Roles.RoleID = UserRoles.RoleID
					INNER JOIN AccessLevels ON AccessLevels.AccessLevelID = UserRoles.AccessLevelID
					INNER JOIN Applications ON Applications.ApplicationID = UserRoles.ApplicationID

				WHERE RegionID In(SELECT [Value] FROM ufnSplit(',', @regionIds))
				ORDER BY ADDomain, VisnID, StationID, LastName, FirstName			;
			END
		--ELSE
		--	BEGIN
		--	   SELECT ADDomain, LastName, FirstName, RoleName, AccessLevelName, ApplicationName, RegionID, VisnID, StationID, AccessStatus, PointOfContact, ShowPII, Comments, UserName
		--		FROM UserRoles
		--			INNER JOIN Users ON Users.UserID = UserRoles.UserID
		--			INNER JOIN Roles ON Roles.RoleID = UserRoles.RoleID
		--			INNER JOIN AccessLevels ON AccessLevels.AccessLevelID = UserRoles.AccessLevelID
		--			INNER JOIN Applications ON Applications.ApplicationID = UserRoles.ApplicationID

		--		ORDER BY ADDomain, VisnID, StationID, LastName, FirstName			
		--	END

       END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the BTER Closed Reasons Details' + CHAR(13) ;
		SELECT * FROM dbo.ufnGetErrorInfo();
		EXEC uspRaiseErrorInfo;
	END CATCH

	DECLARE @webMessage varchar(400)
	SET @webMessage= 'AD Domains: ' + 
		CASE WHEN LEN(@ADDomains) > 0 THEN @ADDomains ELSE 'None specified' END
		 + ', Region Ids: :' + 
		 CASE WHEN LEN(@regionIds) > 0 THEN @regionIds ELSE 'None specified' END

	EXEC uspSaveRptParameters @userId, 'uspRptUserRoles', @webMessage;

END

GO


