﻿-- =============================================
-- Description:	Returns detail data for from web logs for reporting.
-- =============================================
CREATE PROCEDURE [dbo].[uspRptWebLogDetails]
	-- Add the parameters for the stored procedure here
	@minRequestDate datetime,
	@maxRequestDate datetime,
	@adDomains varchar(max),
	@actionTypes varchar(max),
	@requestPages varchar(max)
AS
BEGIN
	DECLARE @tmpMaxDate datetime
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	BEGIN TRY
		--to make sure the full day has been returned, add a day to the maxRequestDate
		IF @maxRequestDate Is Not Null
			BEGIN
				SET @tmpMaxDate = DATEADD(day, 1, @maxRequestDate);
			END
		--make sure the max date is not less than the min date
		IF @tmpMaxDate <= @minRequestDate
			BEGIN
				SET @tmpMaxDate = DATEADD(day, 1, @minRequestDate);
			END

		SELECT ADDomain, UserName, RequestDate, RemoteAddress, 
			RequestPage, ActionType, RecordID, WebMessage
		FROM WebLogs 
		WHERE (RequestDate >= @minRequestDate OR @minRequestDate IS NULL)
			AND (RequestDate <= @tmpMaxDate OR @tmpMaxDate IS NULL)
			AND (ADDomain In(SELECT [Value] FROM ufnSplit(',', @adDomains)) OR @adDomains IS NULL)
			AND (ActionType In(SELECT [Value] FROM ufnSplit(',', @actionTypes)) OR @actionTypes IS NULL)
			AND (RequestPage In(SELECT [Value] FROM ufnSplit(',', @requestPages)) OR @requestPages IS NULL)
		ORDER BY RequestDate, ADDomain, UserName, RequestPage;
	END TRY

	BEGIN CATCH
		PRINT 'There was an error processing the detail web logs report' + CHAR(13);
		SELECT * FROM dbo.ufnGetErrorInfo();
	END CATCH
END