﻿CREATE TABLE dbo.IgnoredItems

(
	--fields
	ItemID				[int] IDENTITY(1,1) NOT NULL,
	ParentItemID		INT NULL,
	ItemTypeID			tinyint NOT NULL,
	StationID			smallint NULL, --NULL in case generated item will be ignored.  (just to prep for extending beyond claims, or variable point A)
	ApplicationID       tinyint NOT NULL,
	ItemName			varchar (50) NOT NULL,
	DateCreated			datetime2(7) NULL,
	DateUpdated			datetime2(7) NULL



	--Primary key
	CONSTRAINT PK_ItemsToIgnore Primary KEY CLUSTERED 
	(
		ItemID ASC
	)
 ) 
GO

--foreign keys
ALTER TABLE dbo.IgnoredItems
	ADD CONSTRAINT FK_IgnoredItems_ParentItemID 
	FOREIGN KEY (ParentItemID)
	REFERENCES IgnoredItems (ItemID)
GO

ALTER TABLE dbo.IgnoredItems
	ADD CONSTRAINT FK_IgnoredItems_ItemTypeID
	FOREIGN KEY (ItemTypeID)
	REFERENCES ItemTypes (ItemTypeID)
GO

ALTER TABLE dbo.IgnoredItems
	ADD CONSTRAINT FK_IgnoredItems_StationID
	FOREIGN KEY (StationID)
	REFERENCES Stations (StationID)
GO

ALTER TABLE dbo.IgnoredItems
	ADD CONSTRAINT FK_IgnoredItems_ApplicationID
	FOREIGN KEY (ApplicationID)
	REFERENCES seclyr.Applications (ApplicationID)
GO



--indexes

CREATE NONCLUSTERED INDEX IX_IgnoredItems_ItemName ON dbo.IgnoredItems
	(
	ItemName
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_IgnoredItems_ItemTypeID ON dbo.IgnoredItems
	(
	ItemTypeID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'ItemID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, self-referential key', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'ParentItemID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, refers to ItemTypes table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'ItemTypeID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, refers to Stations table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'StationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, refers to Applications table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'ApplicationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'name of the item to be ignored', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'ItemName'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date record was created', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'DateCreated'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date record was last updated', 
N'SCHEMA', N'dbo', 
N'TABLE', N'IgnoredItems', 
N'COLUMN', N'DateUpdated'
GO

