CREATE TABLE dbo.ReplicationLogEvents
(
	--fields
	ReplicationLogID		bigint IDENTITY(1,1) NOT NULL,
	ReplicationID			bigint NOT NULL,
	LogDate    				datetime2(7) NOT NULL,
	LogType					varchar (30) NOT NULL, -- example values can be Warning, Notice, Critical	
	ItemTypeID		    	tinyint NULL,
	ItemName				varchar (100) NULL,	
	ErrorOccurred			bit NOT NULL,
	LogMessage				varchar (256) NULL,
	LogDetail				varchar (2048) NULL,

	--Primary key
	CONSTRAINT PK_ReplicationLogEvents Primary KEY CLUSTERED 
	(
		ReplicationLogID ASC
	)    
 ) 
GO

--foreign keys
ALTER TABLE dbo.ReplicationLogEvents
	ADD CONSTRAINT FK_ReplicationLogEvents_ItemTypeID
	FOREIGN KEY (ItemTypeID)
	REFERENCES dbo.ItemTypes (ItemTypeID)
GO

ALTER TABLE dbo.ReplicationLogEvents
	ADD CONSTRAINT FK_ReplicationLogEvents_ReplicationID
	FOREIGN KEY (ReplicationID)
	REFERENCES dbo.ReplicationLogs (ReplicationID)
GO

--indexes
CREATE NONCLUSTERED INDEX IX_ReplicationLogs_ItemTypeID ON dbo.ReplicationLogEvents
	(
	ItemTypeID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_ReplicationLogs_ItemName ON dbo.ReplicationLogEvents
	(
	ItemName
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_ReplicationLogs_LogType ON dbo.ReplicationLogEvents
	(
	LogType
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_ReplicationLogs_LogMessage ON dbo.ReplicationLogEvents
	(
	LogMessage
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

--constraints


GO

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'ReplicationLogID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Replication table',  
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'ReplicationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to ItemTypes table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'ItemTypeID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Name of the Item replicated', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'ItemName'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date the Item was replicated', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', 'LogDate'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Action status for the record entry (synchronize, fail) text', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'LogType'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'true/false, if this record is related to an error', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'ErrorOccurred'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'The message reported to the user', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'LogMessage'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'The details of the log message; this can be anything including a detailed technical explanation', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogEvents', 
N'COLUMN', N'LogDetail'
