﻿CREATE TABLE [dbo].ReplicationLogs
(
	--fields
	ReplicationID			bigint IDENTITY(1,1) NOT NULL,
	ReplicationDate			datetime2 NOT NULL,
	StationID				smallint NOT NULL,
	VistaUserID				int NOT NULL,

	--Primary key
	CONSTRAINT PK_ReplicationLogs Primary KEY CLUSTERED 
	(
		ReplicationID ASC
	)	
)
GO

--foreign keys
ALTER TABLE dbo.ReplicationLogs
	ADD CONSTRAINT FK_ReplicationLogs_Stations
	FOREIGN KEY (StationID)
	REFERENCES dbo.Stations (StationID)
GO

ALTER TABLE dbo.ReplicationLogs
	ADD CONSTRAINT FK_ReplicationLogs_VistaUsers
	FOREIGN KEY (VistaUserID)
	REFERENCES dbo.VistaUsers (VistaUserID)
GO

--indexes
CREATE NONCLUSTERED INDEX IX_ReplicationLogs_ReplicationDate ON dbo.ReplicationLogs
	(
	ReplicationDate
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_Replications_StationID ON dbo.ReplicationLogs
	(
	StationID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_Replications_VistaUser ON dbo.ReplicationLogs
	(
	VistaUserID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogs', 
N'COLUMN', N'ReplicationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date of Replication', 
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogs', 
N'COLUMN', N'ReplicationDate'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Stations table',  
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogs', 
N'COLUMN', N'StationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to VistaUsers table',  
N'SCHEMA', N'dbo', 
N'TABLE', N'ReplicationLogs', 
N'COLUMN', N'VistaUserID'
GO