﻿CREATE TABLE seclyr.UserRoles
(
	--fields
	UserRoleID			[int] IDENTITY(1,1) NOT NULL,
	UserID				[int] NOT NULL,
	RoleID				[tinyint] NOT NULL,
	AccessLevelID		[tinyint] NOT NULL,
	ApplicationID		[tinyint] NOT null,
	RegionID			[tinyint],
	VisnID				[tinyint],
	StationID			[smallint],
	CreatedByUserID		[int],
	UpdatedByUserID		[int],
	DateCreated			[datetime2](7),
	DateUpdated			[datetime2](7),
	AccessStatus		[varchar] (30) NOT NULL,	
	PointOfContact		[bit] NOT NULL,
	ShowPII				[bit] NOT NULL,
	Comments			[varchar](200),

	--primary key
	CONSTRAINT PK_UserRoles PRIMARY KEY CLUSTERED 
	(
		UserRoleID ASC
	),

	----unique key
	--CONSTRAINT UK_UserRoles UNIQUE NONCLUSTERED 
	--(
	--	UserID ASC,
	--	RoleID ASC,
	--	AccessLevelID ASC,
	--	ApplicationID ASC,
	--	RegionID ASC,
	--	VisnID ASC,
	--	StationID ASC
	--),
 ) 
GO

--foreign keys
ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT [FK_UserRoles_CreatedByUserID] 
	FOREIGN KEY (CreatedByUserID)
	REFERENCES seclyr.Users (UserID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT [FK_UserRoles_UpdatedByUserID]
	FOREIGN KEY (UpdatedByUserID)
	REFERENCES seclyr.Users (UserID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT FK_UserRoles_Roles 
	FOREIGN KEY (RoleID)
	REFERENCES seclyr.Roles (RoleID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT FK_UserRoles_Users 
	FOREIGN KEY (UserID)
	REFERENCES seclyr.Users (UserID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT FK_UserRoles_AccessLevels 
	FOREIGN KEY (AccessLevelID)
	REFERENCES seclyr.AccessLevels (AccessLevelID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT FK_UserRoles_Regions 
	FOREIGN KEY (RegionID)
	REFERENCES dbo.Regions (RegionID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT FK_UserRoles_Visns 
	FOREIGN KEY (VisnID)
	REFERENCES dbo.Visns (VisnID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT FK_UserRoles_Stations
	FOREIGN KEY (StationID)
	REFERENCES dbo.Stations (StationID)
GO

ALTER TABLE seclyr.UserRoles
	ADD CONSTRAINT FK_UserRoles_Applications
	FOREIGN KEY (ApplicationID)
	REFERENCES seclyr.Applications (ApplicationID)
GO


--indexes
CREATE NONCLUSTERED INDEX IX_UserRoles_RoleID ON seclyr.UserRoles
	(
	RoleID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

CREATE NONCLUSTERED INDEX IX_UserRoles_UserID ON seclyr.UserRoles
	(
	UserID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_UserRoles_AccessLevelID ON seclyr.UserRoles
	(
	AccessLevelID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_UserRoles_AccessStatus ON seclyr.UserRoles
	(
	AccessStatus
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

--constraints
ALTER TABLE seclyr.UserRoles
   ADD CONSTRAINT DF_Users_PointOfContact
   DEFAULT 0
   FOR PointOfContact
GO

ALTER TABLE seclyr.UserRoles
   ADD CONSTRAINT DF_Users_ShowPII
   DEFAULT 0
   FOR ShowPII
GO

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'UserRoleID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Users table',  
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'UserID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Roles table',  
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'RoleID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to AccessLevels table', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'AccessLevelID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Application table', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'ApplicationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Regions table',  
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'RegionID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Visns table',  
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'VisnID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Stations table',  
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'StationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Users table, User id who created the record', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'CreatedByUserID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Users table, User id who last updated the record', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'UpdatedByUserID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date record was created', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'DateCreated'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date record was last updated', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'DateUpdated'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Status of the user role', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'AccessStatus'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'True/false is the user a point of contact in this role', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'PointOfContact'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'True/false is the user allowed to see PII data in this role', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'ShowPII'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Comments about the user role', 
N'SCHEMA', N'seclyr', 
N'TABLE', N'UserRoles', 
N'COLUMN', N'Comments'
GO
