﻿CREATE TABLE dbo.VistaUsers
(
	--fields
	VistaUserID				[int] IDENTITY(1,1) NOT NULL,
	StationID				[smallint] NOT NULL,
	ADDomain				[varchar] (20) NOT NULL,
	ADUsername    			[varchar](50) NOT NULL,
	VistaUserFullName		[varchar](100) NOT NULL,
	VistaUserIEN		    [varchar](10) NOT NULL,
	VistaService   			[varchar](50),
	DateCreated				[datetime2](7), 
	DateUpdated				[datetime2](7),
	DateLastLogin			[datetime2](7),
	DateInactive			[datetime2](7),
	Inactive				[bit] NOT NULL,

	--Primary key
	CONSTRAINT PK_VistaUsers Primary KEY CLUSTERED 
	(
		VistaUserID ASC
	)

 ) 
GO

--foreign keys
ALTER TABLE dbo.VistaUsers
	ADD CONSTRAINT FK_VistaUsers_Stations
	FOREIGN KEY (StationID)
	REFERENCES dbo.Stations (StationID)
GO

--indexes
CREATE NONCLUSTERED INDEX IX_VistaUsers_Station ON dbo.VistaUsers
	(
	StationID
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_VistaUsers_ADUsername ON dbo.VistaUsers
	(
	ADUsername
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_VistaUsers_VistaUserFullName ON dbo.VistaUsers
	(
	VistaUserFullName
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_VistaUsers_VistaUserIEN ON dbo.VistaUsers
	(
	VistaUserIEN
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO

CREATE NONCLUSTERED INDEX IX_VistaUsers_VistaService ON dbo.VistaUsers
	(
	VistaService
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) 
GO


--constraints
ALTER TABLE dbo.VistaUsers
   ADD CONSTRAINT DF_VistaUsers_Inactive
   DEFAULT 0
   FOR Inactive
GO



--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Primary Key', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'VistaUserID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Foreign Key, relates to Stations table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'StationID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Windows Active Directory domain where the user is logging in from', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'ADDomain'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Windows Active Directory account used to log in to VRAM', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'ADUsername'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Name of the user in VistA', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'VistaUserFullName'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Vista Claims account used to log in to VRAM, VistA IEN', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'VistaUserIEN'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Vista Service/Section from the Claims Vista', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'VistaService'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date record was created', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'DateCreated'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date user entered record', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'DateUpdated'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date user last logged in', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'DateLastLogin'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date record was inactivated', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'DateInactive'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Identifies if the record is inactive', 
N'SCHEMA', N'dbo', 
N'TABLE', N'VistaUsers', 
N'COLUMN', N'Inactive'
GO
