﻿CREATE TABLE dbo.WebLogs
(
	--fields
	WebLogID		[bigint] IDENTITY(1,1) NOT NULL,
	ADDomain		[varchar] (20),
	UserName		[varchar] (60),
	RequestDate		[datetime2](7),
	RemoteAddress	[varchar](50),
	RequestPage		[varchar](100),
	ActionType		[varchar](50),
	RecordID		[varchar](50),
	WebMessage		[varchar](4000),
    ActionCriteria	[xml],

	--primary key
	CONSTRAINT PK_WebLogs PRIMARY KEY CLUSTERED 
	(
		WebLogID ASC
	)
	
	--unique key (if any)
) 
GO

--foreign keys

--indexes
CREATE NONCLUSTERED INDEX IX_WebLogs_ADDomain ON dbo.WebLogs
	(
	ADDomain
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

CREATE NONCLUSTERED INDEX IX_WebLogs_UserName ON dbo.WebLogs
	(
	UserName
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

CREATE NONCLUSTERED INDEX IX_WebLogs_RequestDate ON dbo.WebLogs
	(
	RequestDate
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

CREATE NONCLUSTERED INDEX IX_WebLogs_RequestPage ON dbo.WebLogs
	(
	RequestPage
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO

CREATE NONCLUSTERED INDEX IX_WebLogs_ActionType ON dbo.WebLogs
	(
	ActionType
	) WITH( STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
GO
--constraints

--Metadata descriptions for each field
EXECUTE sp_addextendedproperty 
N'MS_Description', N'Unique Key for the table', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'WebLogID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Windows Active Directory domain where the user is logging in from', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'ADDomain'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'AD Account for the person', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'UserName'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Date of the web action', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'RequestDate'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Internet protocol address of the web action', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'RemoteAddress'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Name of the web page', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'RequestPage'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Describes the action that occured', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'ActionType'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Record identifier, variable key', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'RecordID'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'Custom message, could be a description note or an error message', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'WebMessage'
GO

EXECUTE sp_addextendedproperty 
N'MS_Description', N'XML-format containing the criteria that was performed in the action (e.g., report filter criteria selected)', 
N'SCHEMA', N'dbo', 
N'TABLE', N'WebLogs', 
N'COLUMN', N'ActionCriteria'
GO