﻿using WebVRAM.Data.Domain;
using System.Collections.Generic;
using System.Linq;

namespace WebVRAM.Data.Repository
{
    public class UserRolesRepository : GenericRepository<UserRole>
    {
        public UserRolesRepository(WebVRAM_Entities context)
        {
            Context = context;
            DbSet = context.Set<UserRole>();
        }

        public List<UserRole> GetUserRolesForVisnForApp(byte appId, byte? visnId)
        {
            return
                (from userRole in Context.UserRoles
                    where userRole.ApplicationID == appId && userRole.VisnID == visnId
                    select userRole).ToList();
        }

        public List<string> GetUserRoles(int userId)
        {
            return (from users in Context.Users
                join userRoles in Context.UserRoles on users.UserID equals userRoles.UserID
                join roles in Context.Roles on userRoles.RoleID equals roles.RoleID
                where users.UserID == userId
                select roles.RoleName).ToList();
        }

        public List<UserRole> GetUserRolesByUserId(int userId)
        {
            return (from userRole in Context.UserRoles where userRole.UserID == userId select userRole).ToList();
        }

        public List<UserRole> GetRolesByUserName(string userName)
        {
            return
                (from userRole in Context.UserRoles where userRole.User.UserName == userName select userRole)
                    .ToList();
        }

        public List<string> GetAccessRequestStatusLevels()
        {
            return (from u in Context.uspGetUserRoleStatuses() select u).ToList();
        }
    }
}