﻿using System;
using System.Collections.Generic;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.Primitives;

namespace WebVRAM.Vista.Data.Tests.Common
{
    public class FlexConfigurationSection : IConfigurationSection
    {
        protected IChangeToken ImmutableChangeToken = new ImmutableChangeToken();

        protected Dictionary<string, string> Dictionary = null;
        protected Dictionary<string, IConfigurationSection> Children = new Dictionary<string, IConfigurationSection>();

        public string this[string key]
        {
            get => Dictionary?[key];
            set
            {
                if (Dictionary == null)
                {
                    Dictionary = new Dictionary<string, string>();
                }

                Dictionary[key] = value;
            }
        }

        public string Key { get; set; }

        public string Path => "";

        public string Value { get; set; }

        public IEnumerable<IConfigurationSection> GetChildren()
        {
            return new List<IConfigurationSection>(Children.Values);
        }

        public IChangeToken GetReloadToken()
        {
            return ImmutableChangeToken;
        }

        public IConfigurationSection GetSection(string key)
        {
            return Children.ContainsKey(key) ? Children[key] : null;
        }

        public void AddSection(string key, IConfigurationSection sec)
        {
            Children.Add(key, sec);
        }
    }

    class ImmutableChangeToken : IChangeToken
    {
        public bool HasChanged => false;

        public bool ActiveChangeCallbacks => false;

        public IDisposable RegisterChangeCallback(Action<object> callback, object state)
        {
            return null;
        }
    }
}