﻿using System;
using System.Collections.Generic;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Microsoft.Extensions.Logging;
using WebVRAM.Vista.Service;
using Microsoft.Extensions.Configuration;
using Microsoft.AspNetCore.Http;
using System.Security.Claims;
using Vista.RPC;
using WebVRAM.Web.ng.Common;
using Vista.RPC.Procedures;
using Vista.RPC.Procedures.DDR;
using Vista.RPC.Procedures.XUS;
using Vista.RPC.Procedures.XWB;
using WebVRAM.Vista.Data.Tests.Common;
using WebVRAM.Vista.Services;
using WebVRAM.Web.ng.Models;

namespace WebVRAM.Vista.Service.Tests.Service
{
    /// <summary>
    /// Summary description for UnitTest1
    /// </summary>
    [TestClass]
    public class SyncServiceTests : IHttpContextAccessor, IRpcClientFactory, IRpcSocketFactory, IRpcSocket
    {
        DefaultHttpContext httpContext;

        //TestRpcClient testRpcClient;
        RpcClient testRpcClient2;
        bool _rpcSocketConnected = false;
        string _localIpAddress;
        string _localHostName;
        List<List<object>> rpcSocketCalls = new List<List<object>>();
        List<string> rpcSocketParamStrings = new List<string>();

        public SyncServiceTests()
        {
        }

        private TestContext testContextInstance;

        /// <summary>
        ///Gets or sets the test context which provides
        ///information about and functionality for the current test run.
        ///</summary>
        public TestContext TestContext
        {
            get => testContextInstance;
            set => testContextInstance = value;
        }

        // IHttpContextAccessor property implementation
        public HttpContext HttpContext
        {
            get => httpContext;
            set => throw new NotImplementedException();
        }

        // IRpcSocket interface implementation
        public bool Connected
        {
            get => _rpcSocketConnected;
            set => _rpcSocketConnected = value;
        }

        public string LocalIpAddress
        {
            get
            {
                string returnValue = "";
                if (Connected)
                {
                    returnValue = _localIpAddress;
                }

                rpcSocketCalls.Add(new List<object>() {"LocalIpAddress", returnValue});
                return returnValue;
            }
        }

        public string LocalHostName
        {
            get
            {
                rpcSocketCalls.Add(new List<object>() {"LocalHostName", _localHostName});
                return _localHostName;
            }
        }

        #region Additional test attributes

        //
        // You can use the following additional attributes as you write your tests:
        //
        // Use ClassInitialize to run code before running the first test in the class
        // [ClassInitialize()]
        // public static void MyClassInitialize(TestContext testContext) { }
        //
        // Use ClassCleanup to run code after all tests in a class have run
        // [ClassCleanup()]
        // public static void MyClassCleanup() { }
        //
        // Use TestInitialize to run code before running each test 
        // [TestInitialize()]
        // public void MyTestInitialize() { }
        //
        // Use TestCleanup to run code after each test has run
        // [TestCleanup()]
        // public void MyTestCleanup() { }
        //

        #endregion

        [TestInitialize()]
        public void MyTestInitialize()
        {
            httpContext = new DefaultHttpContext();
            httpContext.User = GetTestUser();
            _rpcSocketConnected = false;
            _localIpAddress = "IP";
            _localHostName = "DNS.URL       ";
        }

        protected virtual ClaimsPrincipal GetTestUser()
        {
            ClaimsPrincipal claimsPrincipal = new ClaimsPrincipal();
            claimsPrincipal.AddIdentity(getUserId());
            return claimsPrincipal;
        }

        protected virtual ClaimsIdentity getUserId()
        {
            var claims = new List<Claim>
            {
                new Claim(ClaimTypes.Name, "MyUser"),
                new Claim(ClaimTypes.NameIdentifier, "MyUserID"),
                new Claim(ClaimTypes.Role, "MyRole"),
                new Claim(JwtPrivateClaims.AccessCode, "stuff1"),
                new Claim(JwtPrivateClaims.VerifyCode, "stuff2")
            };
            ClaimsIdentity id = new ClaimsIdentity(claims, "CustomApiKeyAuth");
            return id;
        }

        [TestMethod]
        public void GetVistaSites_happyPath()
        {
            ILogger<SyncService> logger = TestLogger.Create<SyncService>();
            SyncService service = new SyncService(logger, GetVistaConfig(), GetTestUser(), null); // TODO Mock object
            //service.RpcClientFactory = this; // this shouldn't be needed

            Dictionary<string, Models.VistaSite> sites = service.GetVistaSites();
            Assert.AreEqual(12, rpcSocketCalls.Count);
            Assert.AreEqual("Call", rpcSocketCalls[8][0]);
            DdrGets ddrGets = (DdrGets) rpcSocketCalls[8][1];
            Assert.AreEqual("DDR GETS ENTRY DATA", ddrGets.RpcName);
            Assert.AreEqual("Call", rpcSocketCalls[9][0]);
            DdrLister ddrLister = (DdrLister) rpcSocketCalls[9][1];
            Assert.AreEqual("DDR LISTER", ddrLister.RpcName);
            Assert.IsTrue(rpcSocketParamStrings[6]
                .Contains("if $extract($piece(^(0),U,4))'=\"@\",$data(^R1(100100.0343,\"AU\",DUZ,+Y))"));
        }

        protected virtual IConfigurationSection getTestConfigSection()
        {
            FlexConfigurationSection root = new FlexConfigurationSection();
            FlexConfigurationSection vistaConfig = new FlexConfigurationSection();
            vistaConfig["Hostname"] = "DNS.URL";
            vistaConfig["RpcPort"] = "9100";
            vistaConfig["VramMenuOption"] = "VRAM IS HERE BABY";
            root.AddSection("Vista", vistaConfig);
            return root;
        }

        protected virtual VistaConfig GetVistaConfig()
        {
            var vistaConfig = new VistaConfig("DNS.URL", PORT,
                "VRAM IS HERE BABY".ToSecureString(), "UNKNOWN".ToSecureString());

            return vistaConfig;
        }

        // IRpcClientFactory methods
        public IRpcClient Create(string hostname, int port, bool preventRpcTimeout = true)
        {
            var logger = RpcLogging.CreateLogger<RpcClient>();
            testRpcClient2 = new RpcClient(logger, hostname, port, preventRpcTimeout);
            testRpcClient2.RpcSocketFactory = this;
            return this.testRpcClient2;
        }

        // IRpcSocketFactory methods
        public IRpcSocket Create()
        {
            return this;
        }

        // IRpcSocket interface implementation
        public void Connect(string host, int port)
        {
            rpcSocketCalls.Add(new List<object>() {"Connect", host + ":" + port});
            Connected = true;
        }

        public void Call(IRemoteProcedure rpc)
        {
            rpcSocketCalls.Add(new List<object>() {"Call", rpc});
            if (!Connected)
            {
                throw new Exception("not connected");
            }

            rpcSocketParamStrings.Add(rpc.ToProcedure());
            if (rpc is AvCode)
            {
                rpc.SetResponse("123\r\n0\r\n\r\n");
            }
            else if (rpc is Connect)
            {
                rpc.SetResponse("accept");
            }
            else if (rpc is CreateContext)
            {
                rpc.SetResponse("1");
            }
            else
            {
                rpc.SetResponse("");
            }
        }

        public void Disconnect()
        {
            rpcSocketCalls.Add(new List<object>() {"Disconnect", ""});
            Connected = false;
        }

        public void Dispose()
        {
            
        }
    }
}