using System;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using WebVRAM.Web.ng.Models;

namespace WebVRAM.Web.ng.Controllers.MVC
{
    public class HomeController : Controller
    {
        public static readonly string WEBVRAM = nameof(WEBVRAM);
        
        private ILogger _logger;
        private IHostingEnvironment _environment;

        public HomeController(ILogger<HomeController> logger, IHostingEnvironment environment)
        {
            _logger = logger;
            _environment = environment;
        }

        public IActionResult Index()
        {
            // perform a check to ensure the path ends in a forward slash
            var path = HttpContext.Request.Path;
            if (!path.ToString().EndsWith("/"))
            {
                return Redirect(path.ToString() + "/");
            }

            // setup empty video model
            var viewModel = new HomeViewModel()
            {
                HostingEnvironment = _environment.EnvironmentName
            };

            // determine the path base so that resources (js/css/img) can be loaded correctly
            var pathBase = HttpContext.Request.PathBase;
            if (string.IsNullOrEmpty(pathBase))
            {
                pathBase = "/";
            }

            if (!pathBase.ToString().EndsWith("/"))
            {
                viewModel.BasePath = pathBase.ToString() + "/";

                //ViewBag.Base = pathBase.ToString() + "/";
            }
            else
            {
                viewModel.BasePath = pathBase;

                //ViewBag.Base = pathBase;
            }
            
            // set the secure cookie for authentication and authorization purposes
            var cookieOptions = new CookieOptions()
            {
                HttpOnly = true,
                Secure = true,
                SameSite = SameSiteMode.Strict,
                IsEssential = true,
                Expires = DateTimeOffset.Now.AddDays(7)
            };

            var existingCookie = HttpContext.Request.Cookies[WEBVRAM];
            var cookieValue = existingCookie ?? Guid.NewGuid().ToString();
            HttpContext.Response.Cookies.Append(WEBVRAM, cookieValue, cookieOptions);
            viewModel.Xsrf = cookieValue;

            // log the request
            _logger.LogDebug($"View HomeController/Index; {viewModel}");

            return View(viewModel);
        }

    }
}