﻿using System;
using System.Net;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
using WebVRAM.Web.ng.Models;

namespace WebVRAM.Web.ng.Middleware
{
    public class ExceptionMiddleware
    {
        private readonly RequestDelegate _next;

        private const string JsonContentType = "application/json";

        public ExceptionMiddleware(RequestDelegate next)
        {
            _next = next;
        }

        public async Task InvokeAsync(HttpContext httpContext, ILogger<ExceptionMiddleware> logger)
        {
            if (logger == null)
            {
                throw new ArgumentNullException(nameof(logger));
            }

            try
            {
                await _next(httpContext);
            }
            catch (Exception e)
            {
                logger.LogError(e, $"Exception middleware caught {e.Message}");
                await HandleExceptionAsync(httpContext, e);
            }
        }

        private Task HandleExceptionAsync(HttpContext httpContext, Exception exception)
        {
            var response = httpContext.Response;
            response.ContentType = JsonContentType;
            response.StatusCode = (int) HttpStatusCode.InternalServerError;

            return response.WriteAsync(new ErrorDetails()
            {
                StatusCode = response.StatusCode,
                Message = "Internal server error"
            }.ToString());
        }
    }
}
