﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security;
using System.Threading.Tasks;

namespace WebVRAM.Web.ng.Models
{
    public class JwtConfig
    {
        public JwtConfig(string jwtRegisteredClaims, int jwtExpiration, SecureString jwtSecurityKey, SecureString jwtSignatureKey)
        {
            JwtRegisteredClaims = jwtRegisteredClaims;
            JwtExpiration = jwtExpiration;
            JwtSecurityKey = jwtSecurityKey;
            JwtSignatureKey = jwtSignatureKey;
        }

        /// <summary>
        /// The specific registered claim name; should be unique between environments
        /// </summary>
        public string JwtRegisteredClaims { get; private set; }

        /// <summary>
        /// JwtExpiration, the token's expiration date; in number of days
        /// </summary>
        public int JwtExpiration { get; private set; }
        
        /// <summary>
        /// JwtSecurityKey (AES256KW) MUST be 32 bytes
        /// </summary>
        public SecureString JwtSecurityKey { get; private set; }
        
        /// <summary>
        /// JwtSignatureKey (HMAC_SHA512) SHOULD be >= 64 bytes
        /// </summary>
        public SecureString JwtSignatureKey { get; private set; }
    }
}
