﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Server.HttpSys;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.Logging;
using Serilog;
using Serilog.Events;

namespace WebVRAM.Web.ng
{
    public class Program
    {
        public static readonly string JETBRAINS_RIDER = nameof(JETBRAINS_RIDER);
        
        public static int Main(string[] args)
        {
            Log.Logger = new LoggerConfiguration()
                .MinimumLevel.Debug()
                .MinimumLevel.Override("Microsoft", LogEventLevel.Information)
                .Enrich.FromLogContext()
                .WriteTo.Console()
                .WriteTo.RollingFile("Log\\log.txt")
                .CreateLogger();

            try
            {
                CreateWebHostBuilder(args).Build().Run();

                return 0;
            }
            catch (Exception e)
            {
                Log.Fatal(e, "Host terminated unexpectedly");
                return -1;
            }
            finally
            {
                Log.CloseAndFlush();
            }
        }

        public static IWebHostBuilder CreateWebHostBuilder(string[] args)
        {
            var webHost = WebHost.CreateDefaultBuilder(args)
                .UseStartup<Startup>()
                .UseSerilog();

// if the VisualStudio Solution Configuration is set to Production then 
// have ASP.NET Core load up the production environment
#if PRODUCTION
            webHost.UseEnvironment("Production");
#endif
#if DEBUG
            // if the developers IDE is JetBrains Rider then use HttpSys 
            if (args.Contains(JETBRAINS_RIDER))
            {
                webHost.UseHttpSys(options =>
                {
                    options.Authentication.Schemes = AuthenticationSchemes.NTLM;
                    //options.Authentication.AllowAnonymous = true; // DISABLED since IAM not integrated
                });
            }
#endif
            return webHost;
        }
    }
}
