using System;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authentication.JwtBearer;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.SignalR;
using Microsoft.Extensions.Logging;
using WebVRAM.Vista.Service;
using WebVRAM.Vista.Service.Models;
using WebVRAM.Vista.Services;
using WebVRAM.Web.ng.Models;

namespace WebVRAM.Web.ng.SignalR
{
    [Authorize(Policy = JwtBearerDefaults.AuthenticationScheme)]
    public class VistaHub : Hub
    {
        private ILogger _logger;
        private SyncService _syncService;

        public VistaHub(ILogger<VistaHub> logger, SyncService syncService)
        {
            _logger = logger;
            _syncService = syncService;
        }
        
        public override Task OnConnectedAsync()
        {
            _logger.LogInformation("signalr connected");
            return base.OnConnectedAsync();
        }

        public override Task OnDisconnectedAsync(Exception exception)
        {
            _logger.LogInformation("signalr disconnected");
            return base.OnDisconnectedAsync(exception);
        }

        public async Task<ReflectionSession> SyncToVista(string vistaSiteIen)
        {
            var webSocketClientIpAddress = Context.GetHttpContext().Connection.RemoteIpAddress.ToString();

            var progress = new Progress<ProgressDialog>(dialog =>
            {
                Clients.Caller.SendAsync("updateProgress", dialog);
            });

            var synchronizationResult = await _syncService.SynchronizeToSite(vistaSiteIen, webSocketClientIpAddress, progress);

            return new ReflectionSession
            {
                VistaHostname = synchronizationResult.VistaSite.VistaHostname,
                VistaRpcPort = synchronizationResult.VistaSite.VistaPort,
                SshUsername = synchronizationResult.VistaSite.ShellUsername,
                StationName = synchronizationResult.VistaSite.DisplayName,
                OneTimeUseToken = synchronizationResult.SignOnToken,
                IsSuccessful = synchronizationResult.SuccessfullySynchronized
            };
        }

        public async Task<ReflectionSession> FakeSyncToVista(string vistaSiteIen)
        {
            var progress = new Progress<ProgressDialog>(dialog =>
            {
                Clients.Caller.SendAsync("updateProgress", dialog);
            });

            var progressDialog = (IProgress<ProgressDialog>) progress;
            for (int i = 0; i < 100; i++)
            {
                if (i % 10 == 0)
                {
                    progressDialog.Report(new ProgressDialog()
                    {
                        Message = i.ToString(),
                        PercentComplete = i
                    });
                }
                
                await Task.Delay(50);
            }

            return new ReflectionSession()
            {
                IsSuccessful = true,
                VistaHostname = "DNS.URL"
            };
        }
    }
}