module.exports = function (grunt) {

    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),

        cssmin: {
            options: {
                mergeIntoShorthands: false,
                roundingPrecision: -1
            },
            target: {
                files: {
                    'wwwroot/css/lib.min.css': [
                        'wwwroot/css/bootstrap.css',
                        'wwwroot/css/angular-motion.css',
                        'wwwroot/css/bootstrap-additions.css'
                    ],
                    'wwwroot/css/app.min.css': [
                        'wwwroot/css/app.css'
                    ]
                }
            }
        },
        
        uglify: {
            options: {
                compress: { unused: true, dead_code: true }
            },
            build: {
                files: {
                    'wwwroot/js/lib.min.js': [
                        // jquery
                        'wwwroot/scripts/jquery/jquery-3.3.1.min.js',
                        
                        // bootstrap
                        'wwwroot/scripts/bootstrap/bootstrap.min.js',
                        
                        // angular                        
                        'wwwroot/scripts/ng/angular.min.js',
                        'wwwroot/scripts/ng/angular-route.min.js',
                        'wwwroot/scripts/ng/angular-cookies.min.js',
                        'wwwroot/scripts/ng/angular-animate.min.js',
                        'wwwroot/scripts/ng/angular-aria.min.js',
                        'wwwroot/scripts/ng/angular-messages.min.js',
                        'wwwroot/scripts/ng/angular-touch.min.js',
                        'wwwroot/scripts/ng/angular-sanitize.min.js',

                        // angular-strap
                        'wwwroot/scripts/angular-strap/angular-strap.js',
                        'wwwroot/scripts/angular-strap/angular-strap.tpl.js',
                        
                        // signalr hub
                        'wwwroot/scripts/signalr/signalr.min.js',
                        
                        // angular idle
                        'wwwroot/scripts/ng-idle/angular-idle.js',
                        
                        // spin
                        'wwwroot/scripts/spin.min.js',
                        'wwwroot/scripts/spin.helper.js',
                        
                        // dataTables
                        'wwwroot/scripts/dataTables/jquery.dataTables.js',
                        'scripts/dataTables/dataTables.bootstrap.js'
                    ],
                    'wwwroot/js/app.min.js': [
                        // configs and constants
                        'wwwroot/ng/app-config.js',
                        'wwwroot/ng/app-events.js',
                        'wwwroot/ng/app-session.js',

                        // app run
                        'wwwroot/ng/app.js',
                        
                        // directives
                        'wwwroot/ng/directives/vistaDirective.js',
                        'wwwroot/ng/directives/progressBar.js',
                        
                        // controllers
                        'wwwroot/ng/controllers/idleController.js',
                        'wwwroot/ng/controllers/termsController.js',
                        'wwwroot/ng/controllers/loginController.js',
                        'wwwroot/ng/controllers/mainController.js',
                        'wwwroot/ng/controllers/toolbarController.js',
                        'wwwroot/ng/controllers/signatureController.js',

                        // services
                        'wwwroot/ng/services/sessionService.js',
                        'wwwroot/ng/services/vistaService.js'
                    ]
                }
            }
        },

        watch: {
            scripts: {
                files: ['wwwroot/scripts/**/*.js', 'wwwroot/ng/**/*.js', '!wwwroot/ng/**/*.spec.js'],
                tasks: ['uglify']    
            },
            css: {
                files: ['wwwroot/css/*.css', '!wwwroot/css/*.min.css'],
                tasks: ['cssmin']
            }
            
        }
    });

    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-contrib-cssmin');

    grunt.registerTask('default', ['uglify', 'cssmin', 'watch']);

};