﻿'use strict';

angular
    .module('WebVRAM', ['ngAria', 'ngAnimate', 'mgcrea.ngStrap', /*'SignalR',*/ 'ngRoute', 'ngMessages', 'ngIdle'])
    .config(['$routeProvider', '$locationProvider', '$logProvider', '$compileProvider', 'IdleProvider', 
        function ($routeProvider, $locationProvider, $logProvider, $compileProvider, IdleProvider) {
            $locationProvider.html5Mode(false);
        $compileProvider.debugInfoEnabled(APP.DEBUG);
        $logProvider.debugEnabled(APP.LOG);

        $compileProvider.commentDirectivesEnabled(false);
        $compileProvider.cssClassDirectivesEnabled(false);
        
        // configure Idle settings
        if (APP.IDLE_ENABLED) {
            IdleProvider.idle(APP.IDLE_TIME); // in seconds
            IdleProvider.timeout(APP.IDLE_TIMEOUT); // in seconds
        }

        // configure the routes
        $routeProvider
            .when('/terms', {
                templateUrl: APP.VIEWS + 'terms.html',
                controller: 'TermsController'
            })
            .when('/main', {
                templateUrl: APP.VIEWS + 'main.html',
                controller: 'MainController'
            })
            .when('/login', {
                templateUrl: APP.VIEWS + 'login.html',
                controller: 'LoginController'
            })
            .when('/logout', {
                templateUrl: APP.VIEWS + 'logout.html',
                controller: 'LoginController'
            })
            .when('/help',
            {
                templateUrl: APP.VIEWS + 'help.html'
            })
            .when('/logs',
            {
                templateUrl: APP.VIEWS + 'logs.html'
            })
            .otherwise('/login');
    }])
    .run(['$rootScope', '$location', '$log', 'SessionService', 'Idle', function ($rootScope, $location, $log, SessionService, Idle) {
        
        // start the idle timer
        if (APP.IDLE_ENABLED) {
            Idle.watch();
        }

        $rootScope.$on('$locationChangeStart', function (event, next, current) {
            // have the terms been accepted?
            var termsAccepted = SessionService.Get(SESSION.TERMS_ACCEPTED);

            $log.debug("route next: " + next);
            $log.debug("route current: " + current);

            // allow access of logout even though terms not accepted
            if (next.lastIndexOf('/logout') > 0 && !termsAccepted) {
                $location.path('/logout');
                return;
            }

            // redirect to terms page if terms have not been accepted
            if ($location.path() !== '/terms' && !termsAccepted) {
                $location.path('/terms');
                return;
            }

            // redirect to login page if not logged in and trying to access a restricted page
            var restrictedPage = $.inArray($location.path(), ['/login', '/logout', '/terms']) === -1;
            var loggedIn = SessionService.Get(SESSION.JWT);

            if (restrictedPage && !loggedIn) {
                $location.path('/login');
                return;
            }

            if (loggedIn && $location.path() === '/login') {
                $location.path('/main');
                return;
            }
        });
    }]);