﻿(function () {
    'use strict';

    function MainController($scope, $compile, $modal, SessionService, VistaService) {        

        showSpin(); // show spinner on initial load        

        var vistaSites = VistaService.GetVistaSites().then(function(response) {
            $('#vistaSitesTable').DataTable().clear().rows.add(response.data).draw();            
        }, function (response) {
            alert('Unable to fetch VistA sites.');
        }).finally(function() {
            hideSpin();
            $("#vistaSiteSearch").focus();
        });

        var isSignatureCodeSet = VistaService.IsSignatureCodeSet().then(function (response) {
            if (response.data === false) {
                $('#eSignatureModal').modal('show');
                $('#eSignatureModal').one('hidden.bs.modal', function(e) {
                    $('#eSignatureDetailsModal').modal('show');
                });                
            }                        
        });

        var vistaSitesTable = $('#vistaSitesTable')
            .DataTable({
                'dom': '<"top"ip>rt<"bottom"lp><"clear">',
                'bLengthChange': false,
                //'data': vistaSites,
                'order': [[1, "asc"]],
                columns: [
                    { data: 'siteCode', title: 'Station' },
                    { data: 'displayName', title: 'Station Name' },
                    { data: 'state', title: 'State' },
                    {
                        data: 'siteIen', title: '', orderable: false,
                        className: 'dt-body-center dt-tr-min-width',
                        render: function(data, type, full, meta) {
                            if (type === 'display') {
                                return $compile('<vista reflection="launch" cprs="launch" sync="syncOnly" system="' + data + '"></vista>')($scope);
                            }
                            return data;
                        }
                    }
                ]
            });

        $("#vistaSiteSearch").on("keyup search input paste cut", function () {
            vistaSitesTable.search(this.value).draw();
        });
        
        $scope.launch = function (vistaSystemId, launchType) {
            $scope.synchronized = false;

            var progressModal = $modal({
                scope: $scope,
                templateUrl: 'ng/views/modals/progress-bar-modal.tpl.html',
                show: false,
                backdrop: true,
                keyboard: false
            });            

            progressModal.$promise.then(progressModal.show);

            var progressDialogFunction = function(dialog) {
                var percentage = dialog.percentComplete + '%';
                $('#progress-modal-bar').css('width', percentage);
                $('#progress-modal-title').text(dialog.message);
            };

            VistaService.Synchronize(vistaSystemId, progressDialogFunction).then(function (response) {                
                $scope.$apply(function() {
                    $scope.synchronized = true;
                });
                console.log(response);

                if (response.isSuccessful === true) {
                    progressModal.hide();

                    /*
                    var token = JSON.stringify(response);
                    token = btoa(token);

                    if(launchType === 'reflection')
                        window.open('terminal.html?token=' + token, '_blank', 'resizable=1,status=1,width=780,height=660');
                    else if(launchType === 'cprs')
                        window.open('cprs.html?token=' + token, '_blank', 'resizable=0,status=0,width=100,height=100');
                    */
                } else {
                    /*response.Log.forEach(function(logEntry) {
                        $('#progress-modal-details').append('<p>' + logEntry.LogMessage + '</p>');
                    });*/
                    $('#progress-modal-bar').css('width', '100%');
                    $('#progress-modal-title').text("Failed...");
                    $('#progress-modal-bar').removeClass('active').addClass('progress-bar-danger');
                    $('#progress-modal-more-details').click();
                }
                
            });//*/
        };
    };

    angular
        .module('WebVRAM')
        .controller('MainController', ['$scope', '$compile', '$modal', 'SessionService', 'VistaService', MainController]);
})();