﻿(function () {
    'use strict';

    function VistaService($http, $log, SessionService) {

        var signalr = new signalR.HubConnectionBuilder().withUrl("/vistaHub",
            {
                accessTokenFactory: function() {
                    return SessionService.Get(SESSION.JWT);
                }
            }).build();

        var service = {};

        // LoginController
        service.GetMessageOfTheDay = getMessageOfTheDay;
        service.Login = login;

        // VistaController
        service.GetVistaSites = getVistaSites;

        // SyncHub (SignalR)
        service.Synchronize = synchronize;

        // VistaUserController
        service.IsSignatureCodeSet = isSignatureCodeSet;
        service.SetSignatureCode = setSignatureCode;

        // VistaUserController
        service.SetSignatureDetails = setSignatureDetails;
        service.GetSignatureDetails = getSignatureDetails;

        return service;

        function login(accessCode, verifyCode, xsrf) {
            var data = {
                AccessCode: accessCode,
                VerifyCode: verifyCode,
                Xsrf: xsrf
            };

            return $http.post('api/login/', data);
        }

        function getMessageOfTheDay(callback) {
            $http.get('api/login/').then(callback, callback);
        }

        function getVistaSites() {
            return $http.get('api/vista/',
            {
                headers: {'Authorization': 'Bearer ' + SessionService.Get(SESSION.JWT)}
            });
        }

        function synchronize(vistaSystemId, updateProgressFunction) {
            // flush out any existing client methods
            signalr.off("updateProgress");
            signalr.on("updateProgress", updateProgressFunction);

            // start the connection
            return signalr.start().then(function() {
                // synchronize to the requested vista system
                return signalr.invoke("FakeSyncToVista", vistaSystemId)
                    .then(function(synchResult) {
                        // return the synchronization result
                        return synchResult;
                    })
                    .catch(function(error) {
                        console.error(error);
                        return null;
                    })
                    .finally(function() {
                        signalr.stop();
                    });
            });
        }

        function isSignatureCodeSet() {
            return $http.get('api/vistaUser/isElectronicSignatureCodeSet',
            {
                headers: {'Authorization': 'Bearer ' + SessionService.Get(SESSION.JWT)}
            });
        }

        function setSignatureCode(eSignatureCode) {
            return $http.post('api/vistaUser/setElectronicSignatureCode', '',
            {
                params: { newElectronicSignatureCode: eSignatureCode },
                headers: {'Authorization': 'Bearer ' + SessionService.Get(SESSION.JWT)}
            });  
        }

        function setSignatureDetails(eSignatureDetails) {
            return $http.post('api/vistaUser/setElectronicSignatureDetails', eSignatureDetails,
            {
                headers: {'Authorization': 'Bearer ' + SessionService.Get(SESSION.JWT)}
            });
        }

        function getSignatureDetails() {
            return $http.get('api/vistaUser/getElectronicSignatureDetails',
            {
                headers: {'Authorization': 'Bearer ' + SessionService.Get(SESSION.JWT)}
            });
        }

    };

    angular
        .module('WebVRAM')
        .factory('VistaService', ['$http', '$log', 'SessionService', VistaService]);
})();